*A. STATA DATA PREPARATION
clear all 
set more off
set maxvar 32700
set mat 11000
capture log close
*BHPS online documentation*
*https://www.iser.essex.ac.uk/bhps/documentation/volb/allterms.html*

clear all
set maxvar 32700
set more off
*Individual variables from source files #_INDRESP*
foreach w in a b c d e f g h i j k l m n o p q r{
use using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold ind_allvars_`w', replace
}

*append all adult files*
use ind_allvars_a, clear
append using ind_allvars_b
append using ind_allvars_c
append using ind_allvars_d
append using ind_allvars_e
append using ind_allvars_f
append using ind_allvars_g
append using ind_allvars_h
append using ind_allvars_i
append using ind_allvars_j
append using ind_allvars_k
append using ind_allvars_l
append using ind_allvars_m
append using ind_allvars_n
append using ind_allvars_o
append using ind_allvars_p
append using ind_allvars_q
append using ind_allvars_r
replace pid=id if wave==16 & pid==.
drop id

ds, has(type string)
drop `r(varlist)' /*drop string variables*/

egen cdont1=anycount(*), values(-1) /*count number of -1 "don't knows" for each variable - based upon numeric value*/

rename * n_* /*add prefix n_*/
*rename variables with no labels*
rename n_cdont1 cdont1
rename n_hid hid
rename n_pid pid
rename n_pno pno
rename n_x*wght x*wght
rename n_x*wghte x*wghte
rename n_wave wave
rename n_hgra hgra
rename n_l*wght l*wght
rename n_x*wtsw1 x*wtsw1
rename n_x*wtsw2 x*wtsw2
rename n_l*wtsw1 l*wtsw1
rename n_l*wtsw2 l*wtsw2
rename n_l*wtuk1 l*wtuk1
rename n_l*wtuk2 l*wtuk2
rename n_x*wtuk* x*wtuk*
rename n_*asoc00 *asoc00
rename n_j*soc00 j*soc00
rename n_j*sic92 j*sic92

global varlist n_*
*convert all variables with n_ prefix to strings*
foreach x of varlist n_* { 
decode `x', gen(s_`x') 
} 

global varlist s_n_*
*search whether specific text within string*
foreach x of varlist s_n_* {
gen c`x'=strpos(`x', "don't know")		>0
gen d`x'=strpos(`x', "same")		>0
}

egen cdont=rowtotal(cs_*)
label variable cdont "number of times responded 'don't know' to questions"

egen csame=rowtotal(ds_*)
label variable csame "number of times responded 'same' to questions"

gen year=1990+wave

keep pid year cdont csame
sort pid year
save "U:\expectations\data\all variables.dta", replace

*BIG5 code*
use "U:\BHPSall\UKDA-5151-stata8\stata8\oindresp.dta", clear
drop if optrt5c1==-9  
drop if optrt5c1==-7  
drop if optrt5c1==-1  
drop if optrt5c2==-9  
drop if optrt5c2==-7  
drop if optrt5c2==-1  
drop if optrt5c3==-9  
drop if optrt5c3==-7  
drop if optrt5c3==-1  

drop if optrt5e1==-9  
drop if optrt5e1==-7  
drop if optrt5e1==-1  
drop if optrt5e2==-9  
drop if optrt5e2==-7  
drop if optrt5e2==-1  
drop if optrt5e3==-9  
drop if optrt5e3==-7  
drop if optrt5e3==-1  

drop if optrt5a1==-9  
drop if optrt5a1==-7  
drop if optrt5a1==-1  
drop if optrt5a2==-9  
drop if optrt5a2==-7  
drop if optrt5a2==-1  
drop if optrt5a3==-9  
drop if optrt5a3==-7  
drop if optrt5a3==-1  

drop if optrt5n1==-9  
drop if optrt5n1==-7  
drop if optrt5n1==-1  
drop if optrt5n2==-9  
drop if optrt5n2==-7  
drop if optrt5n2==-1  
drop if optrt5n3==-9  
drop if optrt5n3==-7  
drop if optrt5n3==-1  

drop if optrt5o1==-9  
drop if optrt5o1==-7  
drop if optrt5o1==-1  
drop if optrt5o2==-9  
drop if optrt5o2==-7  
drop if optrt5o2==-1  
drop if optrt5o3==-9  
drop if optrt5o3==-7  
drop if optrt5o3==-1  

gen optrt5e3r=0  
recode optrt5e3r 0=7 if optrt5e3==1  
recode optrt5e3r 0=6 if optrt5e3==2  
recode optrt5e3r 0=5 if optrt5e3==3  
recode optrt5e3r 0=4 if optrt5e3==4  
recode optrt5e3r 0=3 if optrt5e3==5  
recode optrt5e3r 0=2 if optrt5e3==6  
recode optrt5e3r 0=1 if optrt5e3==7  

gen optrt5a1r=0  
recode optrt5a1r 0=7 if optrt5a1==1  
recode optrt5a1r 0=6 if optrt5a1==2  
recode optrt5a1r 0=5 if optrt5a1==3  
recode optrt5a1r 0=4 if optrt5a1==4  
recode optrt5a1r 0=3 if optrt5a1==5  
recode optrt5a1r 0=2 if optrt5a1==6  
recode optrt5a1r 0=1 if optrt5a1==7  

gen optrt5n3r=0  
recode optrt5n3r 0=7 if optrt5n3==1  
recode optrt5n3r 0=6 if optrt5n3==2  
recode optrt5n3r 0=5 if optrt5n3==3  
recode optrt5n3r 0=4 if optrt5n3==4  
recode optrt5n3r 0=3 if optrt5n3==5  
recode optrt5n3r 0=2 if optrt5n3==6  
recode optrt5n3r 0=1 if optrt5n3==7  

alpha optrt5c1 optrt5c2 optrt5c3, gen(big5c) 
alpha optrt5e1 optrt5e2 optrt5e3r, gen(big5e)  
alpha optrt5a1r optrt5a2 optrt5a3, gen(big5a)  
alpha optrt5n1 optrt5n2 optrt5n3r, gen(big5n)  
alpha optrt5o1 optrt5o2 optrt5o3, gen(big5o) 
keep pid big5*
sort pid
save "U:\expectations\data\big5.dta", replace

cd "U:\expectations\data\"

*regional UE data from NOMIS convert from Excel and reshape long*
import excel "U:\Expectations\nomis_regionalUE.xlsx", sheet("RegUE") firstrow clear
reshape long y, i(regcode) j(year)
rename y ue_all 
saveold ue, replace

*amount spent on durables in wave b*
use "U:\BHPS91-08\UKDA-5151-stata8\stata8\bhhresp.dta",clear
renpfix b
gen cdbght=0
recode cdbght 0=1 if cdnuxp>0 & cdnuxp~=.
gen wave=0
keep hid wave cdbght cd*new
save hh_dur_b, replace

 *Household durables variables from source files #_HHRESP wave c onwards*
foreach w in c d e f g h i j k l m n o p q r{
use `w'hid `w'cdbght `w'cd*new using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'hhresp.dta",clear
renpfix `w'
ge wave=index("cdefghijklmnopqr","`w'")
sort hid wave 
saveold hh_dur_`w', replace
}

*append and merge all hh data files*
use hh_dur_b, clear
append using hh_dur_c
append using hh_dur_d
append using hh_dur_e
append using hh_dur_f
append using hh_dur_g
append using hh_dur_h
append using hh_dur_i
append using hh_dur_j
append using hh_dur_k
append using hh_dur_l
append using hh_dur_m
append using hh_dur_n
append using hh_dur_o
append using hh_dur_p
append using hh_dur_q
append using hh_dur_r
replace wave=wave+2
sort hid wave
saveold hh_dur_all, replace
 
*Household variables from source files #_HHRESP*
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid `w'tenure `w'nkids `w'hsval `w'fihhml `w'fihhmnl `w'fihhyr `w'hhsize `w'fihhmi `w'mgxty* `w'mgnew `w'xpfood `w'nch* using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'hhresp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold hh_`w', replace
}

*append and merge all hh data files*
use hh_a, clear
append using hh_b
append using hh_c 
append using hh_d
append using hh_e
append using hh_f
append using hh_g
append using hh_h
append using hh_i
append using hh_j
append using hh_k
append using hh_l
append using hh_m
append using hh_n
append using hh_o
append using hh_p
append using hh_q
append using hh_r

sort hid wave
saveold hh_all, replace

*Household variables from source files #_HHRESP 1997 onwards - expenditure*
foreach w in g h i j k l m n o p q r{
use `w'hid `w'cd*cst using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'hhresp.dta",clear
renpfix `w'
ge wave=index("ghijklmnopqr","`w'")
sort hid wave 
saveold hh_exp_`w', replace
}

*append and merge all hh data files*
use hh_exp_g, clear
append using hh_exp_h
append using hh_exp_i
append using hh_exp_j
append using hh_exp_k
append using hh_exp_l
append using hh_exp_m
append using hh_exp_n
append using hh_exp_o
append using hh_exp_p
append using hh_exp_q
append using hh_exp_r

replace wave=wave+6
sort hid wave
saveold hh_exp_all, replace

*Household variables from source files #_HHRESP 1992-1996 onwards - expenditure*
foreach w in b c d e f{
use `w'hid `w'cdnuxp using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'hhresp.dta",clear
renpfix `w'
ge wave=index("bcdef","`w'")
sort hid wave 
saveold hh_exp_`w', replace
}

*append and merge all hh data files*
use hh_exp_b, clear
append using hh_exp_c
append using hh_exp_d
append using hh_exp_e
append using hh_exp_f

replace wave=wave+1
sort hid wave
saveold hh_exp_9296, replace

*Individual variables from source files #_INDRESP 1997 onwards - leisure expenditure*
foreach w in g h i j k l m n o p q r{
use pid `w'xpleis using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("ghijklmnopqr","`w'")
saveold ind_exp_`w', replace
}

*append and merge all ind data files*
use ind_exp_g, clear
append using ind_exp_h
append using ind_exp_i
append using ind_exp_j
append using ind_exp_k
append using ind_exp_l
append using ind_exp_m
append using ind_exp_n
append using ind_exp_o
append using ind_exp_p
append using ind_exp_q
append using ind_exp_r

replace wave=wave+6
replace pid=id if pid==.
drop id

sort pid wave
saveold ind_exp_all, replace

*Household variables from source files #_LADISTC*
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid `w'ladistc using "U:\Expectations\BHPS lads/`w'ladistc.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold hh_lad_`w', replace
}

*append and merge all hh data files*
use hh_lad_a, clear
append using hh_lad_b
append using hh_lad_c 
append using hh_lad_d
append using hh_lad_e
append using hh_lad_f
append using hh_lad_g
append using hh_lad_h
append using hh_lad_i
append using hh_lad_j
append using hh_lad_k
append using hh_lad_l
append using hh_lad_m
append using hh_lad_n
append using hh_lad_o
append using hh_lad_p
append using hh_lad_q
append using hh_lad_r

sort hid wave
saveold hh_lad_all, replace

*Interviewer ID variable from source files #_HHSAMP*
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid `w'ivid using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'hhsamp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold hh_ivid_`w', replace
}

*append and merge all hh data files*
use hh_ivid_a, clear
append using hh_ivid_b
append using hh_ivid_c 
append using hh_ivid_d
append using hh_ivid_e
append using hh_ivid_f
append using hh_ivid_g
append using hh_ivid_h
append using hh_ivid_i
append using hh_ivid_j
append using hh_ivid_k
append using hh_ivid_l
append using hh_ivid_m
append using hh_ivid_n
append using hh_ivid_o
append using hh_ivid_p
append using hh_ivid_q
append using hh_ivid_r

sort hid wave
saveold hh_ivid_all, replace

*Individual pension variables from source files #_INDRESP wave b onwards*
foreach w in b c d e f g h i j k l m n o p q r{
use pid `w'hid `w'penadd `w'penadv `w'penadw `w'pppen using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("bcdefghijklmnopqr","`w'")
saveold ind_pen_`w', replace
}

*append all adult files*
use ind_pen_b, clear
append using ind_pen_c
append using ind_pen_d
append using ind_pen_e
append using ind_pen_f
append using ind_pen_g
append using ind_pen_h
append using ind_pen_i
append using ind_pen_j
append using ind_pen_k
append using ind_pen_l
append using ind_pen_m
append using ind_pen_n
append using ind_pen_o
append using ind_pen_p
append using ind_pen_q
append using ind_pen_r

replace pid=id if pid==. & wave==15
replace wave=wave+1
drop id
sort pid wave
save ind_pen_all, replace

*Individual variables from source files #_INDRESP*
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid pid `w'age `w'sex `w'qfedhi `w'jbstat `w'mlstat `w'mastat `w'fimnl `w'fimnnl `w'region `w'fisit* `w'saved `w'paygl `w'paygw /*
*/ `w'race `w'fiyr `w'ghq* `w'payslp `w'iv1 `w'iv4 `w'ivfa `w'iv6* `w'ivsoi* `w'ivfoi* `w'jssat2 `w'jbsat4 `w'hlghq2 /*
*/ `w'jbopps `w'jbsat* `w'lkmovy `w'doby `w'hlprb* `w'hoh using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold ind_`w', replace
}

*append all adult files*
use ind_a, clear
append using ind_b
append using ind_c
append using ind_d
append using ind_e
append using ind_f
append using ind_g
append using ind_h
append using ind_i
append using ind_j
append using ind_k
append using ind_l
append using ind_m
append using ind_n
append using ind_o
append using ind_p
append using ind_q
append using ind_r

sort hid wave
save ind_all, replace

merge hid wave using hh_all
drop if _merge~=3
drop _merge

sort hid wave
merge hid wave using hh_lad_all
drop if _merge==2
drop _merge

sort hid wave
merge hid wave using hh_ivid_all
drop if _merge~=3
drop _merge

replace pid=id if wave==16 & pid==.
encode ivid, gen(intid)
sort pid wave
xtset pid wave
gen chivid=0
recode chivid 0=1 if intid~=L.intid
label variable chivid "1=change in interviewer between waves, 0=otherwise"

*year*
gen year=1990+wave
tab year, gen(yr)
label variable year "year of interview"
drop yr1 yr2/*drop 1991 and 1992*/
*recode pid*
replace pid=id if wave==16 & pid==.
drop id
*number of adults*
gen nadult=hhsize-nkids
recode nadult 0=1
*gender*
drop if sex<0
recode sex 2=0
label variable sex "gender: 0=female, 1=male"
*keep individual aged 16 andn over*
drop if age<18 | age>65
label variable age "age of individual"
gen agesq=age^2
label variable agesq "age squared"
*age bands*
gen a_1830=0
gen a_3140=0
gen a_4150=0
recode a_1830 0=1 if age<31
recode a_3140 0=1 if age>30 & age<41
recode a_4150 0=1 if age>40 & age<51
label variable a_1830 "1=aged between 18 and 30, 0=otherwise"
label variable a_3140 "1=aged between 31 and 40, 0=otherwise"
label variable a_4150 "1=aged between 41 and 50, 0=otherwise"
*highest educational attainment*
xtset pid year
bys pid year: gen record = qfedhi[1] if _n == 1 
bys pid: replace record = max(qfedhi, record[_n - 1]) if qfedhi==. | qfedhi<0
drop qfedhi
rename record qfedhi
gen deg=0
gen ohigh=0
gen alev=0
gen olev=0
gen othed=0
recode deg 0=1 if qfedhi==1 | qfedhi==2
label variable deg "1=degree, 0=otherwise"
recode ohigh 0=1 if qfedhi==3 | qfedhi==4 | qfedhi==5
label variable ohigh "1=other higher qualification, 0=otherwise"
recode alev 0=1 if qfedhi==6
label variable alev "1=alevels, 0=otherwise"
recode olev 0=1 if qfedhi==7
label variable olev "1=olevels, 0=otherwise"
recode othed 0=1 if qfedhi>=8 & qfedhi<12
label variable othed "1=other education, 0=otherwise"
*number of kids*
recode nkids -9 . =0 6 7 8 9 =5
label variable nkids "number of children"
*marital status*
gen marr=0
recode marr 0=1 if mlstat==1 | mastat==1 | mastat==2
label variable marr "1=marrried or cohabiting, 0=otherwise"
*labour market status*
gen emp=0
gen semp=0
gen unemp=0
recode emp 0=1 if jbstat==2
label variable emp "1=employee, 0=otherwise"
recode semp 0=1 if jbstat==1
label variable semp "1=self employed, 0=otherwise"
recode unemp 0=1 if jbstat==3
label variable unemp "1=unemployed, 0=otherwise"
*housing tenure*
gen ownor=0
gen mort=0
gen rentc=0
recode ownor 0=1 if tenure==1
label variable ownor "1=own home outright, 0=otherwise"
recode mort 0=1 if tenure==2
label variable mort "1=own home on a mortgage, 0=otherwise"
recode rentc 0=1 if tenure==3
label variable rentc "1=rent home, 0=otherwise"
*gross monthly pay*
replace paygl=0 if paygl<0 | paygl==.
gen mon_pay=0
replace mon_pay=paygl*4 if paygw==1
replace mon_pay=paygl*2 if paygw==2
replace mon_pay=paygl*(4/3) if paygw==3
replace mon_pay=paygl if paygw==4 | (paygw>4 & paygw<5)
replace mon_pay=paygl/12 if paygw==52
*household labour income*
replace fihhml=0 if fihhml<0 | fihhml==.
*individual labour income*
replace fimnl=0 if fimnl<0 | fimnl==.
rename fimnl labinc /*last month*/
replace labinc=mon_pay if labinc==0 & mon_pay~=0
replace labinc=fihhml/nadult if labinc==0
replace labinc=(labinc/100)*103.75 if year==1992
replace labinc=(labinc/100)*105.39 if year==1993
replace labinc=(labinc/100)*107.94 if year==1994
replace labinc=(labinc/100)*111.69 if year==1995
replace labinc=(labinc/100)*114.38 if year==1996
replace labinc=(labinc/100)*117.98 if year==1997
replace labinc=(labinc/100)*122.02 if year==1998
replace labinc=(labinc/100)*123.90 if year==1999
replace labinc=(labinc/100)*127.57 if year==2000
replace labinc=(labinc/100)*129.81 if year==2001
replace labinc=(labinc/100)*131.99 if year==2002
replace labinc=(labinc/100)*135.81 if year==2003
replace labinc=(labinc/100)*139.85 if year==2004
replace labinc=(labinc/100)*143.82 if year==2005
replace labinc=(labinc/100)*148.39 if year==2006
replace labinc=(labinc/100)*154.76 if year==2007
replace labinc=(labinc/100)*160.90 if year==2008
gen llab=log(labinc+1)
recode llab .=0
label variable llab "log labour income last month"
*household non labour income*
replace fihhmnl=0 if fihhmnl<0 | fihhmnl==.
*individual non labour income*
replace fimnnl=0 if fimnnl<0 | fimnnl==.
rename fimnnl nlabinc /*last month*/
replace nlabinc=fihhmnl/nadult if nlabinc==0
replace nlabinc=(nlabinc/100)*103.75 if year==1992
replace nlabinc=(nlabinc/100)*105.39 if year==1993
replace nlabinc=(nlabinc/100)*107.94 if year==1994
replace nlabinc=(nlabinc/100)*111.69 if year==1995
replace nlabinc=(nlabinc/100)*114.38 if year==1996
replace nlabinc=(nlabinc/100)*117.98 if year==1997
replace nlabinc=(nlabinc/100)*122.02 if year==1998
replace nlabinc=(nlabinc/100)*123.90 if year==1999
replace nlabinc=(nlabinc/100)*127.57 if year==2000
replace nlabinc=(nlabinc/100)*129.81 if year==2001
replace nlabinc=(nlabinc/100)*131.99 if year==2002
replace nlabinc=(nlabinc/100)*135.81 if year==2003
replace nlabinc=(nlabinc/100)*139.85 if year==2004
replace nlabinc=(nlabinc/100)*143.82 if year==2005
replace nlabinc=(nlabinc/100)*148.39 if year==2006
replace nlabinc=(nlabinc/100)*154.76 if year==2007
replace nlabinc=(nlabinc/100)*160.90 if year==2008
gen lnlab=log(nlabinc+1)
recode lnlab .=0
label variable lnlab "log non labour income last month"
*sum of labour and non labour income*/
gen inc=labinc+nlabinc
drop if inc==0 /*drop those individuals with no income*/
*savings*
replace saved=0 if saved<0 | saved==. /*last month*/
replace saved=(saved/100)*103.75 if year==1992
replace saved=(saved/100)*105.39 if year==1993
replace saved=(saved/100)*107.94 if year==1994
replace saved=(saved/100)*111.69 if year==1995
replace saved=(saved/100)*114.38 if year==1996
replace saved=(saved/100)*117.98 if year==1997
replace saved=(saved/100)*122.02 if year==1998
replace saved=(saved/100)*123.90 if year==1999
replace saved=(saved/100)*127.57 if year==2000
replace saved=(saved/100)*129.81 if year==2001
replace saved=(saved/100)*131.99 if year==2002
replace saved=(saved/100)*135.81 if year==2003
replace saved=(saved/100)*139.85 if year==2004
replace saved=(saved/100)*143.82 if year==2005
replace saved=(saved/100)*148.39 if year==2006
replace saved=(saved/100)*154.76 if year==2007
replace saved=(saved/100)*160.90 if year==2008
gen lsaved=log(saved+1)
label variable lsaved "log savings last month"
*wealth - house value*
replace hsval=0 if hsval<0 | hsval==. /*last month*/
gen n_hsval=hsval
label variable n_hsval "nominal house value"
replace hsval=(hsval/100)*103.75 if year==1992
replace hsval=(hsval/100)*105.39 if year==1993
replace hsval=(hsval/100)*107.94 if year==1994
replace hsval=(hsval/100)*111.69 if year==1995
replace hsval=(hsval/100)*114.38 if year==1996
replace hsval=(hsval/100)*117.98 if year==1997
replace hsval=(hsval/100)*122.02 if year==1998
replace hsval=(hsval/100)*123.90 if year==1999
replace hsval=(hsval/100)*127.57 if year==2000
replace hsval=(hsval/100)*129.81 if year==2001
replace hsval=(hsval/100)*131.99 if year==2002
replace hsval=(hsval/100)*135.81 if year==2003
replace hsval=(hsval/100)*139.85 if year==2004
replace hsval=(hsval/100)*143.82 if year==2005
replace hsval=(hsval/100)*148.39 if year==2006
replace hsval=(hsval/100)*154.76 if year==2007
replace hsval=(hsval/100)*160.90 if year==2008
gen lhsval=log(hsval+1)
label variable lhsval "log house value"
*investment income month before interview*
replace fihhmi=0 if  fihhmi<0 |  fihhmi==.
gen n_inv=fihhmi
label variable n_inv "nominal investment income"
replace fihhmi=(fihhmi/100)*103.75 if year==1992
replace fihhmi=(fihhmi/100)*105.39 if year==1993
replace fihhmi=(fihhmi/100)*107.94 if year==1994
replace fihhmi=(fihhmi/100)*111.69 if year==1995
replace fihhmi=(fihhmi/100)*114.38 if year==1996
replace fihhmi=(fihhmi/100)*117.98 if year==1997
replace fihhmi=(fihhmi/100)*122.02 if year==1998
replace fihhmi=(fihhmi/100)*123.90 if year==1999
replace fihhmi=(fihhmi/100)*127.57 if year==2000
replace fihhmi=(fihhmi/100)*129.81 if year==2001
replace fihhmi=(fihhmi/100)*131.99 if year==2002
replace fihhmi=(fihhmi/100)*135.81 if year==2003
replace fihhmi=(fihhmi/100)*139.85 if year==2004
replace fihhmi=(fihhmi/100)*143.82 if year==2005
replace fihhmi=(fihhmi/100)*148.39 if year==2006
replace fihhmi=(fihhmi/100)*154.76 if year==2007
replace fihhmi=(fihhmi/100)*160.90 if year==2008
gen linv=log(fihhmi+1)
label variable linv "log real investment income"
*total income last year*
gen n_inc=fiyr
label variable n_inc "nominal income last year"
replace fiyr=(fiyr/100)*103.75 if year==1992
replace fiyr=(fiyr/100)*105.39 if year==1993
replace fiyr=(fiyr/100)*107.94 if year==1994
replace fiyr=(fiyr/100)*111.69 if year==1995
replace fiyr=(fiyr/100)*114.38 if year==1996
replace fiyr=(fiyr/100)*117.98 if year==1997
replace fiyr=(fiyr/100)*122.02 if year==1998
replace fiyr=(fiyr/100)*123.90 if year==1999
replace fiyr=(fiyr/100)*127.57 if year==2000
replace fiyr=(fiyr/100)*129.81 if year==2001
replace fiyr=(fiyr/100)*131.99 if year==2002
replace fiyr=(fiyr/100)*135.81 if year==2003
replace fiyr=(fiyr/100)*139.85 if year==2004
replace fiyr=(fiyr/100)*143.82 if year==2005
replace fiyr=(fiyr/100)*148.39 if year==2006
replace fiyr=(fiyr/100)*154.76 if year==2007
replace fiyr=(fiyr/100)*160.90 if year==2008
label variable fiyr "real income last year"
*total household income*
replace fihhyr=(fihhyr/100)*103.75 if year==1992
replace fihhyr=(fihhyr/100)*105.39 if year==1993
replace fihhyr=(fihhyr/100)*107.94 if year==1994
replace fihhyr=(fihhyr/100)*111.69 if year==1995
replace fihhyr=(fihhyr/100)*114.38 if year==1996
replace fihhyr=(fihhyr/100)*117.98 if year==1997
replace fihhyr=(fihhyr/100)*122.02 if year==1998
replace fihhyr=(fihhyr/100)*123.90 if year==1999
replace fihhyr=(fihhyr/100)*127.57 if year==2000
replace fihhyr=(fihhyr/100)*129.81 if year==2001
replace fihhyr=(fihhyr/100)*131.99 if year==2002
replace fihhyr=(fihhyr/100)*135.81 if year==2003
replace fihhyr=(fihhyr/100)*139.85 if year==2004
replace fihhyr=(fihhyr/100)*143.82 if year==2005
replace fihhyr=(fihhyr/100)*148.39 if year==2006
replace fihhyr=(fihhyr/100)*154.76 if year==2007
replace fihhyr=(fihhyr/100)*160.90 if year==2008
gen lreal_hy=log(fihhyr+1)
label variable lreal_hy "log real household annual income last year"
*wealth*
replace fiyr=0 if fiyr<0
gen wealth=hsval+fihhmi+fiyr
gen n_wealth=n_hsval+n_inv+n_inc
label variable n_wealth "nominal wealth + nominal income"
label variable wealth "real wealth + real income"
gen lwealth=log(wealth+1)
label variable lwealth "log real wealth"
*change in income and wealth*
xtset pid year
gen ch_rinc=D.fiyr
label variable ch_rinc "change in real income last year"
gen ch_ninc=D.n_inc
label variable ch_ninc "change in nominal income last year"
gen ch_nwinc=D.n_wealth
label variable ch_nwinc "change in nominal income and wealth last year"
gen ch_winc=D.wealth
label variable ch_winc "change in real income and wealth last year"
*convert changes in income and wealth to zeros if within +/- 5% sd*
sum ch_ninc
replace ch_ninc=0 if abs(ch_ninc)<(r(sd)*0.05)
sum ch_rinc
replace ch_rinc=0 if abs(ch_rinc)<(r(sd)*0.05)
sum ch_nwinc
replace ch_nwinc=0 if abs(ch_nwinc)<(r(sd)*0.05)
sum ch_winc
replace ch_winc=0 if abs(ch_winc)<(r(sd)*0.05)

*region*
drop if region==-9 | region==19
recode region 2=1 /*create london = inner & outer*/
tab region, gen(rg)
drop rg1 /*london omitted*/
*expectations index 1 - same and don't know equal to zero*
drop if fisitx==-9 | fisitx==-7 | fisitx==-2 | fisitx==-1/*drop (-9) missing or wild; (-7) proxy respondent; (-2) refused; (-1) don't know*/
drop if fisitc==-9 | fisitc==-7 | fisitc==-2 | fisitc==-1/*drop (-9) missing or wild; (-7) proxy respondent; (-2) refused; (-1) don't know*/
gen expind1=.
recode expind1 .=1 if fisitx==3
recode expind1 .=0 if fisitx==2
recode expind1 .=2 if fisitx==1
label variable expind1 "0=pessimistic, 1=same, 2=optimistic"
*ethnicity*
sort pid year
bys pid: gen eth=race[1]
gen white=0
gen black=0
gen asian=0
recode white 0=1 if eth==1
label variable white "1=white, 0=other"
recode black 0=1 if eth==2 | eth==3 | eth==4
label variable black "1=black, 0=other"
recode asian 0=1 if eth==5 | eth==6 | eth==7 | eth==8
label variable asian "1=asian, 0=other"
*1. subjective*
sort pid year
xtset pid year
*correctly optimistic based upon subjective measure of income change*
gen cs_o=0
recode cs_o 0=1 if L.fisitx==1 & fisitc==1
label variable cs_o "1=correctly financially optimistic (subjective), 0=other"
*incorrectly optimistic based upon subjective measure of income change*
gen ics_o=0
recode ics_o 0=1 if L.fisitx==1 & fisitc~=1
label variable ics_o "1=incorrectly financially optimistic (subjective), 0=other"
*correctly pessimistic based upon subjective measure of income change*
gen cs_p=0
recode cs_p 0=1 if L.fisitx==2 & fisitc==2
label variable cs_p "1=correctly financially pessimistic (subjective), 0=other"
*incorrectly pessimistic based upon subjective measure of income change*
gen ics_p=0
recode ics_p 0=1 if L.fisitx==2 & fisitc~=2
label variable ics_p "1=incorrectly financially pessimistic (subjective), 0=other"
*correctly same based upon subjective measure of income change*
gen cs_s=0
recode cs_s 0=1 if L.fisitx==3 & fisitc==3
label variable cs_s "1=correctly financially same (subjective), 0=other"
*incorrectly same based upon subjective measure of income change*
gen ics_s=0
recode ics_s 0=1 if L.fisitx==3 & fisitc~=3
label variable ics_s "1=incorrectly financially same (subjective), 0=other"
*2. objective nominal income*
*correctly optimistic based upon objective measure of nominal income change*
gen cony_o=0
recode cony_o 0=1 if fisitx==1 & ch_ninc>0 & ch_ninc~=.
recode cony_o 0=. if ch_ninc==.
label variable cony_o "1=correctly financially optimistic (nominal income objective), 0=other"
*incorrectly optimistic based upon objective measure of nominal income change*
gen icony_o=0
recode icony_o 0=1 if fisitx==1 & ch_ninc<0 & ch_ninc~=.
recode icony_o 0=. if ch_ninc==.
label variable icony_o "1=incorrectly financially optimistic (nominal income objective), 0=other"
*correctly pessimistic based upon objective measure of nominal income change*
gen cony_p=0
recode cony_p 0=1 if fisitx==2 & ch_ninc<0 & ch_ninc~=.
recode cony_p 0=. if ch_ninc==.
label variable cony_p "1=correctly financially pessimistic (nominal income objective), 0=other"
*incorrectly pessimistic based upon objective measure of nominal income change*
gen icony_p=0
recode icony_p 0=1 if fisitx==2 & ch_ninc>0 & ch_ninc~=.
recode icony_p 0=. if ch_ninc==.
label variable icony_p "1=incorrectly financially pessimistic (nominal income objective), 0=other"
*correctly same based upon objective measure of nominal income change*
gen cony_s=0
recode cony_s 0=1 if fisitx==3 & ch_ninc==0 & ch_ninc~=.
recode cony_s 0=. if ch_ninc==.
label variable cony_s "1=correctly financially same (nominal income objective), 0=other"
*incorrectly same based upon objective measure of nominal income change*
gen icony_s=0
recode icony_s 0=1 if fisitx==3 & ch_ninc~=0 & ch_ninc~=.
recode icony_s 0=. if ch_ninc==.
label variable icony_s "1=correctly financially same (nominal income objective), 0=other"
*3. objective real income*
*correctly optimistic based upon objective measure of real income change*
gen cory_o=0
recode cory_o 0=1 if fisitx==1 & ch_rinc>0 & ch_rinc~=.
recode cory_o 0=. if ch_rinc==.
label variable cory_o "1=correctly financially optimistic (real income objective), 0=other"
*incorrectly optimistic based upon objective measure of real income change*
gen icory_o=0
recode icory_o 0=1 if fisitx==1 & ch_rinc<0 & ch_rinc~=.
recode icory_o 0=. if ch_rinc==.
label variable icory_o "1=incorrectly financially optimistic (real income objective), 0=other"
*correctly pessimistic based upon objective measure of real income change*
gen cory_p=0
recode cory_p 0=1 if fisitx==2 & ch_rinc<0 & ch_rinc~=.
recode cory_p 0=. if ch_rinc==.
label variable cory_p "1=correctly financially pessimistic (real income objective), 0=other"
*incorrectly pessimistic based upon objective measure of real income change*
gen icory_p=0
recode icory_p 0=1 if fisitx==2 & ch_rinc>0 & ch_rinc~=.
recode icory_p 0=. if ch_rinc==.
label variable icory_p "1=incorrectly financially pessimistic (real income objective), 0=other"
*correctly same based upon objective measure of real income change*
gen cory_s=0
recode cory_s 0=1 if fisitx==3 & ch_rinc==0 & ch_rinc~=.
recode cory_s 0=. if ch_rinc==.
label variable cory_s "1=correctly financially same (real income objective), 0=other"
*incorrectly same based upon objective measure of real income change*
gen icory_s=0
recode icory_s 0=1 if fisitx==3 & ch_rinc~=0 & ch_rinc~=.
recode icory_s 0=. if ch_rinc==.
label variable icory_s "1=in correctly financially same (real income objective), 0=other"
*4. objective nominal income + wealth*
*correctly optimistic based upon objective measure of nominal income + wealth change*
gen conw_o=0
recode conw_o 0=1 if fisitx==1 & ch_nwinc>0 & ch_nwinc~=.
recode conw_o 0=. if ch_nwinc==.
label variable conw_o "1=correctly financially optimistic (nominal income + wealth objective), 0=other"
*incorrectly optimistic based upon objective measure of nominal income + wealth change*
gen iconw_o=0
recode iconw_o 0=1 if fisitx==1 & ch_nwinc<0 & ch_nwinc~=.
recode iconw_o 0=. if ch_nwinc==.
label variable iconw_o "1=incorrectly financially optimistic (nominal income + wealth objective), 0=other"
*correctly pessimistic based upon objective measure of nominal income + wealth change*
gen conw_p=0
recode conw_p 0=1 if fisitx==2 & ch_nwinc<0 & ch_nwinc~=.
recode conw_p 0=. if ch_nwinc==.
label variable conw_p "1=correctly financially pessimistic (nominal income + wealth objective), 0=other"
*incorrectly pessimistic based upon objective measure of nominal income + wealth change*
gen iconw_p=0
recode iconw_p 0=1 if fisitx==2 & ch_nwinc>0 & ch_nwinc~=.
recode iconw_p 0=. if ch_nwinc==.
label variable iconw_p "1=incorrectly financially pessimistic (nominal income + wealth objective), 0=other"
*correctly same based upon objective measure of nominal income +wealth change*
gen conw_s=0
recode conw_s 0=1 if fisitx==3 & ch_nwinc==0 & ch_nwinc~=.
recode conw_s 0=. if ch_nwinc==.
label variable conw_s "1=correctly financially same (nominal income + wealth objective), 0=other"
*incorrectly same based upon objective measure of nominal income + wealth change*
gen iconw_s=0
recode iconw_s 0=1 if fisitx==3 & ch_nwinc~=0 & ch_nwinc~=.
recode iconw_s 0=. if ch_nwinc==.
label variable iconw_s "1=incorrectly financially same (nominal income + wealth objective), 0=other"
*5. objective real income + wealth*
*correctly optimistic based upon objective measure of real income +wealth change*
gen corw_o=0
recode corw_o 0=1 if fisitx==1 & ch_winc>0 & ch_winc~=.
recode corw_o 0=. if ch_winc==.
label variable corw_o "1=correctly financially optimistic (real income + wealth objective), 0=other"
*incorrectly optimistic based upon objective measure of real income + wealth change*
gen icorw_o=0
recode icorw_o 0=1 if fisitx==1 & ch_winc<0 & ch_winc~=.
recode icorw_o 0=. if ch_winc==.
label variable icorw_o "1=incorrectly financially optimistic (real income + wealth objective), 0=other"
*correctly pessimistic based upon objective measure of real income + wealth change*
gen corw_p=0
recode corw_p 0=1 if fisitx==2 & ch_winc<0 & ch_winc~=.
recode corw_p 0=. if ch_winc==.
label variable corw_p "1=correctly financially pessimistic (real income + wealth objective), 0=other"
*incorrectly pessimistic based upon objective measure of real income + wealth change*
gen icorw_p=0
recode icorw_p 0=1 if fisitx==2 & ch_winc>0 & ch_winc~=.
recode icorw_p 0=. if ch_winc==.
label variable icorw_p "1=incorrectly financially pessimistic (real income + wealth objective), 0=other"
*correctly same based upon objective measure of real income +wealth change*
gen corw_s=0
recode corw_s 0=1 if fisitx==3 & ch_winc==0 & ch_winc~=.
recode corw_s 0=. if ch_winc==.
label variable corw_s "1=correctly financially same (real income + wealth objective), 0=other"
*incorrectly same based upon objective measure of real income + wealth change*
gen icorw_s=0
recode icorw_s 0=1 if fisitx==3 & ch_winc~=0 & ch_winc~=.
recode icorw_s 0=. if ch_winc==.
label variable icorw_s "1=incorrectly financially same (real income + wealth objective), 0=other"

*extra stuff August*
*1. create dummies off index*
gen opt=0
gen pess=0
gen same=0
recode opt 0=1 if expind==2
recode same 0=1 if expind==1
recode pess 0=1 if expind==0
label variable opt "1=optimistic; 0=otherwise"
label variable pess "1=pessimistic; 0=otherwise"
label variable same "1=same; 0=otherwise"
*2. create lagged index and lagged dummies*
sort pid year
xtset pid year
gen Lexp=L.expind1
label variable Lexp "lagged expectations index"
gen Lopt=L.opt
label variable Lopt "lagged optimistic"
gen Lpess=L.pess
label variable Lpess "lagged pessimistic"
gen Lsame=L.same
label variable Lsame "lagged same"
*3. initial conditions*
sort pid year
bys pid: gen intopt=opt[1]
label variable intopt "initial condition optimistic"
bys pid: gen intpess=pess[1]
label variable intpess "initial condition pessimistic"
bys pid: gen intsame=same[1]
label variable intsame "initial condition same"
*4. rename real and nominal variables*
rename fiyr real_y
rename n_inc nom_y
rename wealth real_w
rename n_wealth nom_w
*6. recode funny values*
recode hlghq2 -9=0
replace nom_w=0 if nom_w<0
replace nom_y=0 if nom_y<0 
*7. create logs of real and nominal variables*
gen lreal_y=log(real_y+1)
label variable lreal_y "natural logarithm of real income"
gen lnom_y=log(nom_y+1)
label variable lnom_y "natural logarithm of nominal income"
gen lreal_w=log(real_w+1)
label variable lreal_w "natural logarithm of real income + real wealth"
gen lnom_w=log(nom_w+1)
label variable lnom_w "natural logarithm of nominal income + nominal wealth"
*8. subjective current financial position*
drop if fisit<1
tab fisit, gen(cfin)
*9.drop missing observations on change variables*
drop if Lopt==.
drop if ch_ninc==.
*10. rename change variables to 7 chars*/
rename ch_ninc ch_ny
rename ch_nwinc ch_nw
rename ch_rinc ch_ry
rename ch_winc ch_rw
*11. generate regional code to match in ue data from NOMIS*
gen regcode=.
recode regcode .=1 if region==10 | region==15 | region==16
recode regcode .=2 if region==11 | region==12 | region==13
recode regcode .=3 if region==14
recode regcode .=4 if region==6
recode regcode .=5 if region==7 | region==8
recode regcode .=6 if region==5 | region==9 | region==10
recode regcode .=7 if region==1
recode regcode .=8 if region==3
recode regcode .=9 if region==4
recode regcode .=10 if region==17
recode regcode .=11 if region==18

sort regcode year
merge regcode year using ue.dta
drop if _merge~=3
drop _merge

label variable ue_all "regional unemployment rate (%) working age 16-65"
gen lue=log(ue_all)
label variable lue "natural logarithm of regional unemployment rate"

*12. create time trend*
gen trend=wave-1
label variable trend "time trend"

/*
*save unbalanced data*
keep pid year expind* age sex a_* nkids marr white black asian deg ohigh alev olev othed emp semp unemp ownor mort rentc llab lnlab lsaved lwealth region year fisit* ch_* *_o *_p rg* yr* 
aorder
save "U:\expectations\exp_unbal_data.dta", replace
*/

*13. merge in pension stuff*
sort pid wave
merge pid wave using ind_pen_all
drop if _merge~=3
drop _merge
*14. subjective changes in financial situation*/
gen y_up=0
gen y_down=0
gen ex_up=0
gen ex_down=0
recode y_up 0=1 if fisity==1 | fisity==2 | fisity==3 | fisity==5
label variable y_up "1=finanical situation income increased (earnings, benefits, inv. income and/or windfall), 0=otherwise"
recode y_down 0=1 if fisity==11 | fisity==12 | fisity==13
label variable y_down "1=financial situation income decreased (earnings, benefits and/or inv. income), 0=otherwise"
recode ex_up 0=1 if fisity==14 | fisity==15
label variable ex_up "1=financial situation expenditure increased, 0=otherwise"
recode ex_down 0=1 if fisity==4
label variable ex_down "1=financial situation expenditure decreased, 0=otherwise"
*15. promotion opportunities in job*
recode jbopps 2 -9 -8 -7 -1 .=0
*16. amount of additional mortgage on home*
replace mgnew=0 if mgnew<0 | mgnew==.
replace mgnew=(mgnew/100)*103.75 if year==1992
replace mgnew=(mgnew/100)*105.39 if year==1993
replace mgnew=(mgnew/100)*107.94 if year==1994
replace mgnew=(mgnew/100)*111.69 if year==1995
replace mgnew=(mgnew/100)*114.38 if year==1996
replace mgnew=(mgnew/100)*117.98 if year==1997
replace mgnew=(mgnew/100)*122.02 if year==1998
replace mgnew=(mgnew/100)*123.90 if year==1999
replace mgnew=(mgnew/100)*127.57 if year==2000
replace mgnew=(mgnew/100)*129.81 if year==2001
replace mgnew=(mgnew/100)*131.99 if year==2002
replace mgnew=(mgnew/100)*135.81 if year==2003
replace mgnew=(mgnew/100)*139.85 if year==2004
replace mgnew=(mgnew/100)*143.82 if year==2005
replace mgnew=(mgnew/100)*148.39 if year==2006
replace mgnew=(mgnew/100)*154.76 if year==2007
replace mgnew=(mgnew/100)*160.90 if year==2008
gen lmgnew=log(mgnew+1)
label variable lmgnew "log real additional value of mortgage"
*17. reasons for additional loan*
recode mgxty1 -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode mgxty2 -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode mgxty3 -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode mgxty4 -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode mgxty5 -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
*18. Total weekly food and grocery bill*
replace xpfood=0 if xpfood<0 | xpfood==.
recode xpfood 0=1
label variable xpfood "£ spent per wk on food/groceries: 1=<£10, 2=£10-£19 .. 11=£140-£159, 12=>£160"
*19. satisfaction with aspects of current job*
replace jbsat=0 if emp==0 | jbsat<0
replace jbsat1=0 if emp==0 | jbsat1<0 | jbsat1==.
replace jbsat2=0 if emp==0 | jbsat2<0 | jbsat2==.
replace jbsat3=0 if emp==0 | jbsat3<0 | jbsat3==.
replace jbsat4=0 if emp==0 | jbsat4<0 | jbsat4==.
replace jbsat5=0 if emp==0 | jbsat5<0 | jbsat5==.
replace jbsat6=0 if emp==0 | jbsat6<0 | jbsat6==.
replace jbsat7=0 if emp==0 | jbsat7<0 | jbsat7==.
*20. additional contrib'n to post '88 pension*
recode penadd -9 -8 -7 -6 -5 -4 -3 -2 -1 2 .=0
*21. amount last payment post 1.7.88 pension*
replace penadv=0 if penadv<0 | penadv==.
replace penadv=penadv*52 if penadw==1 /* £ amount weekly recode to annual*/
replace penadv=penadv*26 if penadw==2 /* £ amount 2 weeks recode to annual*/
replace penadv=penadv*12 if penadw>2 & penadw<9 /* £ amount monthly recode to annual*/
replace penadv=penadv*5.78 if penadw==9 /* £ amount 9 weeks recode to annual*/
replace penadv=penadv*4 if penadw==13 /* £ amount 13 weeks recode to annual*/
replace penadv=penadv*3.06 if penadw==17 /* £ amount 17 weeks recode to annual*/
replace penadv=penadv*2.89 if penadw==18 /* £ amount 18 weeks recode to annual*/
replace penadv=penadv*2 if penadw==26 /* £ amount 26 weeks recode to annual*/
replace penadv=penadv*1.33 if penadw==39 /* £ amount 39 weeks recode to annual*/
replace penadv=(penadv/100)*103.75 if year==1992
replace penadv=(penadv/100)*105.39 if year==1993
replace penadv=(penadv/100)*107.94 if year==1994
replace penadv=(penadv/100)*111.69 if year==1995
replace penadv=(penadv/100)*114.38 if year==1996
replace penadv=(penadv/100)*117.98 if year==1997
replace penadv=(penadv/100)*122.02 if year==1998
replace penadv=(penadv/100)*123.90 if year==1999
replace penadv=(penadv/100)*127.57 if year==2000
replace penadv=(penadv/100)*129.81 if year==2001
replace penadv=(penadv/100)*131.99 if year==2002
replace penadv=(penadv/100)*135.81 if year==2003
replace penadv=(penadv/100)*139.85 if year==2004
replace penadv=(penadv/100)*143.82 if year==2005
replace penadv=(penadv/100)*148.39 if year==2006
replace penadv=(penadv/100)*154.76 if year==2007
replace penadv=(penadv/100)*160.90 if year==2008
gen lpenadv=log(penadv+1)
label variable lpenadv "log real last payment post 1.7.88 pension (annual)"
*22. whether paid into private personal pension*
recode pppen -9 -8 -7 -6 -5 -4 -3 -2 -1 2 .=0
*23. why prefers to move house*
gen move=0
recode move 0=1 if lkmovy==2
label variable move "1= prefers to move: main reason smaller/cheaper acc, 0=other"
*24. whether purchase a consumer durable*
sort hid wave
merge hid wave using hh_dur_all
recode cdbght -9 -8 -7 -6 -5 -4 -3 -2 -1 . 2=0
drop if _merge~=3
drop _merge
label variable cdbght "1=bought a consumer durable in past year, 0=other"
*25. type of consumer durable purchase*
recode cd1new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd2new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd3new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd4new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd5new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd6new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd7new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd8new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd9new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd10new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd11new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd12new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
recode cd13new -9 -8 -7 -6 -5 -4 -3 -2 -1 .=0
*26. number of consumer durables purchased*
gen ncdur1=cd1new+cd2new+cd3new+cd4new+cd5new+cd6new+cd7new+cd8new+cd9new
label variable ncdur1 "number of consumer durables purchased - consistent categories"
egen ncdur2=rsum(cd*new)
label variable ncdur2 "number of consumer durables purchased - all categories"
*27. household appliance/electronics purchase*
gen h_app=0 /*comprising freezers, microwaves, dishwashers,washing machines and tumble dryers*/
recode h_app 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
label variable h_app "1=household appliance purchased made, 0=other"
gen el_app=0 /*personal computers, CD players, televisions, VCRs, phones, cable TV and satellite dishes*/
recode el_app 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1 | cd13new==1
label variable el_app "1=electronics purchase made, 0=other"
*28. consumer durable expenditure*
sort hid wave
merge hid wave using hh_exp_all.dta
drop if _merge==2
drop _merge
sort hid wave
merge hid wave using hh_exp_9296.dta
drop if _merge==2
drop _merge
replace cd1cst=0 if cd1cst<0 | cd1cst==.
replace cd1cst=(cd1cst/100)*103.75 if year==1992
replace cd1cst=(cd1cst/100)*105.39 if year==1993
replace cd1cst=(cd1cst/100)*107.94 if year==1994
replace cd1cst=(cd1cst/100)*111.69 if year==1995
replace cd1cst=(cd1cst/100)*114.38 if year==1996
replace cd1cst=(cd1cst/100)*117.98 if year==1997
replace cd1cst=(cd1cst/100)*122.02 if year==1998
replace cd1cst=(cd1cst/100)*123.90 if year==1999
replace cd1cst=(cd1cst/100)*127.57 if year==2000
replace cd1cst=(cd1cst/100)*129.81 if year==2001
replace cd1cst=(cd1cst/100)*131.99 if year==2002
replace cd1cst=(cd1cst/100)*135.81 if year==2003
replace cd1cst=(cd1cst/100)*139.85 if year==2004
replace cd1cst=(cd1cst/100)*143.82 if year==2005
replace cd1cst=(cd1cst/100)*148.39 if year==2006
replace cd1cst=(cd1cst/100)*154.76 if year==2007
replace cd1cst=(cd1cst/100)*160.90 if year==2008
replace cd2cst=0 if cd2cst<0 | cd2cst==.
replace cd2cst=(cd2cst/100)*103.75 if year==1992
replace cd2cst=(cd2cst/100)*105.39 if year==1993
replace cd2cst=(cd2cst/100)*107.94 if year==1994
replace cd2cst=(cd2cst/100)*111.69 if year==1995
replace cd2cst=(cd2cst/100)*114.38 if year==1996
replace cd2cst=(cd2cst/100)*117.98 if year==1997
replace cd2cst=(cd2cst/100)*122.02 if year==1998
replace cd2cst=(cd2cst/100)*123.90 if year==1999
replace cd2cst=(cd2cst/100)*127.57 if year==2000
replace cd2cst=(cd2cst/100)*129.81 if year==2001
replace cd2cst=(cd2cst/100)*131.99 if year==2002
replace cd2cst=(cd2cst/100)*135.81 if year==2003
replace cd2cst=(cd2cst/100)*139.85 if year==2004
replace cd2cst=(cd2cst/100)*143.82 if year==2005
replace cd2cst=(cd2cst/100)*148.39 if year==2006
replace cd2cst=(cd2cst/100)*154.76 if year==2007
replace cd2cst=(cd2cst/100)*160.90 if year==2008
replace cd3cst=0 if cd3cst<0 | cd3cst==.
replace cd3cst=(cd3cst/100)*103.75 if year==1992
replace cd3cst=(cd3cst/100)*105.39 if year==1993
replace cd3cst=(cd3cst/100)*107.94 if year==1994
replace cd3cst=(cd3cst/100)*111.69 if year==1995
replace cd3cst=(cd3cst/100)*114.38 if year==1996
replace cd3cst=(cd3cst/100)*117.98 if year==1997
replace cd3cst=(cd3cst/100)*122.02 if year==1998
replace cd3cst=(cd3cst/100)*123.90 if year==1999
replace cd3cst=(cd3cst/100)*127.57 if year==2000
replace cd3cst=(cd3cst/100)*129.81 if year==2001
replace cd3cst=(cd3cst/100)*131.99 if year==2002
replace cd3cst=(cd3cst/100)*135.81 if year==2003
replace cd3cst=(cd3cst/100)*139.85 if year==2004
replace cd3cst=(cd3cst/100)*143.82 if year==2005
replace cd3cst=(cd3cst/100)*148.39 if year==2006
replace cd3cst=(cd3cst/100)*154.76 if year==2007
replace cd3cst=(cd3cst/100)*160.90 if year==2008
replace cd4cst=0 if cd4cst<0 | cd4cst==.
replace cd4cst=(cd4cst/100)*103.75 if year==1992
replace cd4cst=(cd4cst/100)*105.39 if year==1993
replace cd4cst=(cd4cst/100)*107.94 if year==1994
replace cd4cst=(cd4cst/100)*111.69 if year==1995
replace cd4cst=(cd4cst/100)*114.38 if year==1996
replace cd4cst=(cd4cst/100)*117.98 if year==1997
replace cd4cst=(cd4cst/100)*122.02 if year==1998
replace cd4cst=(cd4cst/100)*123.90 if year==1999
replace cd4cst=(cd4cst/100)*127.57 if year==2000
replace cd4cst=(cd4cst/100)*129.81 if year==2001
replace cd4cst=(cd4cst/100)*131.99 if year==2002
replace cd4cst=(cd4cst/100)*135.81 if year==2003
replace cd4cst=(cd4cst/100)*139.85 if year==2004
replace cd4cst=(cd4cst/100)*143.82 if year==2005
replace cd4cst=(cd4cst/100)*148.39 if year==2006
replace cd4cst=(cd4cst/100)*154.76 if year==2007
replace cd4cst=(cd4cst/100)*160.90 if year==2008
replace cd5cst=0 if cd5cst<0 | cd5cst==.
replace cd5cst=(cd5cst/100)*103.75 if year==1992
replace cd5cst=(cd5cst/100)*105.39 if year==1993
replace cd5cst=(cd5cst/100)*107.94 if year==1994
replace cd5cst=(cd5cst/100)*111.69 if year==1995
replace cd5cst=(cd5cst/100)*114.38 if year==1996
replace cd5cst=(cd5cst/100)*117.98 if year==1997
replace cd5cst=(cd5cst/100)*122.02 if year==1998
replace cd5cst=(cd5cst/100)*123.90 if year==1999
replace cd5cst=(cd5cst/100)*127.57 if year==2000
replace cd5cst=(cd5cst/100)*129.81 if year==2001
replace cd5cst=(cd5cst/100)*131.99 if year==2002
replace cd5cst=(cd5cst/100)*135.81 if year==2003
replace cd5cst=(cd5cst/100)*139.85 if year==2004
replace cd5cst=(cd5cst/100)*143.82 if year==2005
replace cd5cst=(cd5cst/100)*148.39 if year==2006
replace cd5cst=(cd5cst/100)*154.76 if year==2007
replace cd5cst=(cd5cst/100)*160.90 if year==2008
replace cd6cst=0 if cd6cst<0 | cd6cst==.
replace cd6cst=(cd6cst/100)*103.75 if year==1992
replace cd6cst=(cd6cst/100)*105.39 if year==1993
replace cd6cst=(cd6cst/100)*107.94 if year==1994
replace cd6cst=(cd6cst/100)*111.69 if year==1995
replace cd6cst=(cd6cst/100)*114.38 if year==1996
replace cd6cst=(cd6cst/100)*117.98 if year==1997
replace cd6cst=(cd6cst/100)*122.02 if year==1998
replace cd6cst=(cd6cst/100)*123.90 if year==1999
replace cd6cst=(cd6cst/100)*127.57 if year==2000
replace cd6cst=(cd6cst/100)*129.81 if year==2001
replace cd6cst=(cd6cst/100)*131.99 if year==2002
replace cd6cst=(cd6cst/100)*135.81 if year==2003
replace cd6cst=(cd6cst/100)*139.85 if year==2004
replace cd6cst=(cd6cst/100)*143.82 if year==2005
replace cd6cst=(cd6cst/100)*148.39 if year==2006
replace cd6cst=(cd6cst/100)*154.76 if year==2007
replace cd6cst=(cd6cst/100)*160.90 if year==2008
replace cd7cst=0 if cd7cst<0 | cd7cst==.
replace cd7cst=(cd7cst/100)*103.75 if year==1992
replace cd7cst=(cd7cst/100)*105.39 if year==1993
replace cd7cst=(cd7cst/100)*107.94 if year==1994
replace cd7cst=(cd7cst/100)*111.69 if year==1995
replace cd7cst=(cd7cst/100)*114.38 if year==1996
replace cd7cst=(cd7cst/100)*117.98 if year==1997
replace cd7cst=(cd7cst/100)*122.02 if year==1998
replace cd7cst=(cd7cst/100)*123.90 if year==1999
replace cd7cst=(cd7cst/100)*127.57 if year==2000
replace cd7cst=(cd7cst/100)*129.81 if year==2001
replace cd7cst=(cd7cst/100)*131.99 if year==2002
replace cd7cst=(cd7cst/100)*135.81 if year==2003
replace cd7cst=(cd7cst/100)*139.85 if year==2004
replace cd7cst=(cd7cst/100)*143.82 if year==2005
replace cd7cst=(cd7cst/100)*148.39 if year==2006
replace cd7cst=(cd7cst/100)*154.76 if year==2007
replace cd7cst=(cd7cst/100)*160.90 if year==2008
replace cd8cst=0 if cd8cst<0 | cd8cst==.
replace cd8cst=(cd8cst/100)*103.75 if year==1992
replace cd8cst=(cd8cst/100)*105.39 if year==1993
replace cd8cst=(cd8cst/100)*107.94 if year==1994
replace cd8cst=(cd8cst/100)*111.69 if year==1995
replace cd8cst=(cd8cst/100)*114.38 if year==1996
replace cd8cst=(cd8cst/100)*117.98 if year==1997
replace cd8cst=(cd8cst/100)*122.02 if year==1998
replace cd8cst=(cd8cst/100)*123.90 if year==1999
replace cd8cst=(cd8cst/100)*127.57 if year==2000
replace cd8cst=(cd8cst/100)*129.81 if year==2001
replace cd8cst=(cd8cst/100)*131.99 if year==2002
replace cd8cst=(cd8cst/100)*135.81 if year==2003
replace cd8cst=(cd8cst/100)*139.85 if year==2004
replace cd8cst=(cd8cst/100)*143.82 if year==2005
replace cd8cst=(cd8cst/100)*148.39 if year==2006
replace cd8cst=(cd8cst/100)*154.76 if year==2007
replace cd8cst=(cd8cst/100)*160.90 if year==2008
replace cd9cst=0 if cd9cst<0 | cd9cst==.
replace cd9cst=(cd9cst/100)*103.75 if year==1992
replace cd9cst=(cd9cst/100)*105.39 if year==1993
replace cd9cst=(cd9cst/100)*107.94 if year==1994
replace cd9cst=(cd9cst/100)*111.69 if year==1995
replace cd9cst=(cd9cst/100)*114.38 if year==1996
replace cd9cst=(cd9cst/100)*117.98 if year==1997
replace cd9cst=(cd9cst/100)*122.02 if year==1998
replace cd9cst=(cd9cst/100)*123.90 if year==1999
replace cd9cst=(cd9cst/100)*127.57 if year==2000
replace cd9cst=(cd9cst/100)*129.81 if year==2001
replace cd9cst=(cd9cst/100)*131.99 if year==2002
replace cd9cst=(cd9cst/100)*135.81 if year==2003
replace cd9cst=(cd9cst/100)*139.85 if year==2004
replace cd9cst=(cd9cst/100)*143.82 if year==2005
replace cd9cst=(cd9cst/100)*148.39 if year==2006
replace cd9cst=(cd9cst/100)*154.76 if year==2007
replace cd9cst=(cd9cst/100)*160.90 if year==2008
replace cd10cst=0 if cd10cst<0 | cd10cst==.
replace cd10cst=(cd10cst/100)*103.75 if year==1992
replace cd10cst=(cd10cst/100)*105.39 if year==1993
replace cd10cst=(cd10cst/100)*107.94 if year==1994
replace cd10cst=(cd10cst/100)*111.69 if year==1995
replace cd10cst=(cd10cst/100)*114.38 if year==1996
replace cd10cst=(cd10cst/100)*117.98 if year==1997
replace cd10cst=(cd10cst/100)*122.02 if year==1998
replace cd10cst=(cd10cst/100)*123.90 if year==1999
replace cd10cst=(cd10cst/100)*127.57 if year==2000
replace cd10cst=(cd10cst/100)*129.81 if year==2001
replace cd10cst=(cd10cst/100)*131.99 if year==2002
replace cd10cst=(cd10cst/100)*135.81 if year==2003
replace cd10cst=(cd10cst/100)*139.85 if year==2004
replace cd10cst=(cd10cst/100)*143.82 if year==2005
replace cd10cst=(cd10cst/100)*148.39 if year==2006
replace cd10cst=(cd10cst/100)*154.76 if year==2007
replace cd10cst=(cd10cst/100)*160.90 if year==2008
replace cd11cst=0 if cd11cst<0 | cd11cst==.
replace cd11cst=(cd11cst/100)*103.75 if year==1992
replace cd11cst=(cd11cst/100)*105.39 if year==1993
replace cd11cst=(cd11cst/100)*107.94 if year==1994
replace cd11cst=(cd11cst/100)*111.69 if year==1995
replace cd11cst=(cd11cst/100)*114.38 if year==1996
replace cd11cst=(cd11cst/100)*117.98 if year==1997
replace cd11cst=(cd11cst/100)*122.02 if year==1998
replace cd11cst=(cd11cst/100)*123.90 if year==1999
replace cd11cst=(cd11cst/100)*127.57 if year==2000
replace cd11cst=(cd11cst/100)*129.81 if year==2001
replace cd11cst=(cd11cst/100)*131.99 if year==2002
replace cd11cst=(cd11cst/100)*135.81 if year==2003
replace cd11cst=(cd11cst/100)*139.85 if year==2004
replace cd11cst=(cd11cst/100)*143.82 if year==2005
replace cd11cst=(cd11cst/100)*148.39 if year==2006
replace cd11cst=(cd11cst/100)*154.76 if year==2007
replace cd11cst=(cd11cst/100)*160.90 if year==2008
replace cd12cst=0 if cd12cst<0 | cd12cst==.
replace cd12cst=(cd12cst/100)*103.75 if year==1992
replace cd12cst=(cd12cst/100)*105.39 if year==1993
replace cd12cst=(cd12cst/100)*107.94 if year==1994
replace cd12cst=(cd12cst/100)*111.69 if year==1995
replace cd12cst=(cd12cst/100)*114.38 if year==1996
replace cd12cst=(cd12cst/100)*117.98 if year==1997
replace cd12cst=(cd12cst/100)*122.02 if year==1998
replace cd12cst=(cd12cst/100)*123.90 if year==1999
replace cd12cst=(cd12cst/100)*127.57 if year==2000
replace cd12cst=(cd12cst/100)*129.81 if year==2001
replace cd12cst=(cd12cst/100)*131.99 if year==2002
replace cd12cst=(cd12cst/100)*135.81 if year==2003
replace cd12cst=(cd12cst/100)*139.85 if year==2004
replace cd12cst=(cd12cst/100)*143.82 if year==2005
replace cd12cst=(cd12cst/100)*148.39 if year==2006
replace cd12cst=(cd12cst/100)*154.76 if year==2007
replace cd12cst=(cd12cst/100)*160.90 if year==2008
replace cd13cst=0 if cd13cst<0 | cd13cst==.
replace cd13cst=(cd13cst/100)*103.75 if year==1992
replace cd13cst=(cd13cst/100)*105.39 if year==1993
replace cd13cst=(cd13cst/100)*107.94 if year==1994
replace cd13cst=(cd13cst/100)*111.69 if year==1995
replace cd13cst=(cd13cst/100)*114.38 if year==1996
replace cd13cst=(cd13cst/100)*117.98 if year==1997
replace cd13cst=(cd13cst/100)*122.02 if year==1998
replace cd13cst=(cd13cst/100)*123.90 if year==1999
replace cd13cst=(cd13cst/100)*127.57 if year==2000
replace cd13cst=(cd13cst/100)*129.81 if year==2001
replace cd13cst=(cd13cst/100)*131.99 if year==2002
replace cd13cst=(cd13cst/100)*135.81 if year==2003
replace cd13cst=(cd13cst/100)*139.85 if year==2004
replace cd13cst=(cd13cst/100)*143.82 if year==2005
replace cd13cst=(cd13cst/100)*148.39 if year==2006
replace cd13cst=(cd13cst/100)*154.76 if year==2007
replace cd13cst=(cd13cst/100)*160.90 if year==2008
replace cdnuxp=0 if cdnuxp<0 | cdnuxp==. /*all goods*/
replace cdnuxp=(cdnuxp/100)*103.75 if year==1992
replace cdnuxp=(cdnuxp/100)*105.39 if year==1993
replace cdnuxp=(cdnuxp/100)*107.94 if year==1994
replace cdnuxp=(cdnuxp/100)*111.69 if year==1995
replace cdnuxp=(cdnuxp/100)*114.38 if year==1996
replace cdnuxp=(cdnuxp/100)*117.98 if year==1997
replace cdnuxp=(cdnuxp/100)*122.02 if year==1998
replace cdnuxp=(cdnuxp/100)*123.90 if year==1999
replace cdnuxp=(cdnuxp/100)*127.57 if year==2000
replace cdnuxp=(cdnuxp/100)*129.81 if year==2001
replace cdnuxp=(cdnuxp/100)*131.99 if year==2002
replace cdnuxp=(cdnuxp/100)*135.81 if year==2003
replace cdnuxp=(cdnuxp/100)*139.85 if year==2004
replace cdnuxp=(cdnuxp/100)*143.82 if year==2005
replace cdnuxp=(cdnuxp/100)*148.39 if year==2006
replace cdnuxp=(cdnuxp/100)*154.76 if year==2007
replace cdnuxp=(cdnuxp/100)*160.90 if year==2008
replace cd10cst=0 if year<1997
replace cd11cst=0 if year<1997
replace cd12cst=0 if year<1997
replace cd13cst=0 if year<1997
egen tsp_dur=rsum(cd*cst)
label variable tsp_dur "total real expenditure on durable goods (1997+)"
g tsp_dur2=tsp_dur
replace tsp_dur2=tsp_dur+cdnuxp if tsp_dur==0 | (tsp_dur<cdnuxp)
label variable tsp_dur2 "total real expenditure on durable goods (1992+)"
gen ltsp_dur=log(tsp_dur+1)
label variable ltsp_dur "log real total expenditure on durable goods (1997+)"
gen ltsp_dur2=log(tsp_dur2+1)
label variable ltsp_dur2 "log real total expenditure on durable goods (1992+)"
*29. merge in leisure expenditure*
sort pid wave
merge pid wave using ind_exp_all.dta
drop if _merge==2
drop _merge
replace xpleis=0 if xpleis<0 | xpleis==.
recode xpleis 0=1
replace xpleis=. if year<1997
label variable xpleis "£ spent per month on leisure: 1=<£10, 2=£10-£19 .. 11=£140-£159, 12=>£160"
*28. cohort*
replace doby=year-age if doby==-1
replace doby=doby-1925
label variable doby "year of birth (coded to run 1,2,3,..,c)"
gen doby2=doby^2
label variable doby2 "year of birth squared"
*29. age polynomial*
gen age2=age^2
label variable age2 "age squared"
gen age3=age^3
label variable age3 "age cubed"
gen age4=age^4
label variable age4 "age quartic"
*30. health problems*
drop hlprb hlprb1-hlprb4
replace hlprba=0 if hlprba~=1
replace hlprbb=0 if hlprbb~=1
replace hlprbc=0 if hlprbc~=1
replace hlprbd=0 if hlprbd~=1
replace hlprbe=0 if hlprbe~=1
replace hlprbf=0 if hlprbf~=1
replace hlprbg=0 if hlprbg~=1
replace hlprbh=0 if hlprbh~=1
replace hlprbi=0 if hlprbi~=1
replace hlprbj=0 if hlprbj~=1
replace hlprbk=0 if hlprbk~=1
replace hlprbl=0 if hlprbl~=1
replace hlprbm=0 if hlprbm~=1
replace hlprbn=0 if hlprbn~=1
replace hlprbo=0 if hlprbo~=1
egen nhprobs=rsum(hlprb*)
label variable nhprobs "number of health problems"

*create balanced data*
bys pid: egen pds=count(_N)
keep if pds==17
drop pds
xtset pid year
*code for splitting equations*
*31. number of times correct in forecast and rate - based upon subjective outcome*
bys pid: gen Tcs_o=sum(L.cs_o)
label variable Tcs_o "Number times correctly optimistic subjective"
bys pid: gen Tcs_p=sum(L.cs_p)
label variable Tcs_p "Number times correctly pessimistic subjective"
bys pid: gen Tcs_s=sum(L.cs_s)
label variable Tcs_s "Number times correctly same subjective"
egen Tcs=rsum(Tcs_o Tcs_p Tcs_s)
label variable Tcs "Number times correct subjective"
gen t=year-1991
gen CRs_o=Tcs_o/t
label variable CRs_o "Number times correctly optimistic / time in panel subjective"
gen CRs_p=Tcs_p/t
label variable CRs_p "Number times correctly pessimistic / time in panel subjective"
gen CRs_s=Tcs_s/t
label variable CRs_s "Number times correctly same / time in panel subjective"
gen CRs=Tcs/t
label variable CRs "Number times correct / time in panel subjective"
*32. number of times correct in forecast and rate - based upon objective outcome nominal income*
bys pid: gen Tco1_o=sum(L.cony_o)
label variable Tco1_o "Number times correctly optimistic objective nominal income"
bys pid: gen Tco1_p=sum(L.cony_p)
label variable Tco1_p "Number times correctly pessimistic objective nominal income"
bys pid: gen Tco1_s=sum(L.cony_s)
label variable Tco1_s "Number times correctly same objective nominal income"
egen Tco1=rsum(Tco1_o Tco1_p Tco1_s)
label variable Tco1 "Number times correct objective nominal income"
gen CRo1_o=Tco1_o/t
label variable CRo1_o "Number times correctly optimistic / time in panel objective nominal income"
gen CRo1_p=Tco1_p/t
label variable CRo1_p "Number times correctly pessimistic / time in panel objective nominal income"
gen CRo1_s=Tco1_s/t
label variable CRo1_s "Number times correctly same / time in panel objective nominal income"
gen CRo1=Tco1/t
label variable CRo1 "Number times correct / time in panel objective nominal income"
*33. number of times correct in forecast and rate - based upon objective outcome real income*
bys pid: gen Tco2_o=sum(L.cory_o)
label variable Tco2_o "Number times correctly optimistic objective real income"
bys pid: gen Tco2_p=sum(L.cory_p)
label variable Tco2_p "Number times correctly pessimistic objective real income"
bys pid: gen Tco2_s=sum(L.cory_s)
label variable Tco2_s "Number times correctly same objective real income"
egen Tco2=rsum(Tco2_o Tco2_p Tco2_s)
label variable Tco2 "Number times correct objective real income"
gen CRo2_o=Tco2_o/t
label variable CRo2_o "Number times correctly optimistic / time in panel objective real income"
gen CRo2_p=Tco2_p/t
label variable CRo2_p "Number times correctly pessimistic / time in panel objective real income"
gen CRo2_s=Tco2_s/t
label variable CRo2_s "Number times correctly same / time in panel objective real income"
gen CRo2=Tco2/t
label variable CRo2 "Number times correct / time in panel objective real income"
*34. number of times correct in forecast and rate - based upon objective outcome nominal income + wealth*
bys pid: gen Tco3_o=sum(L.conw_o)
label variable Tco3_o "Number times correctly optimistic objective nominal income + wealth"
bys pid: gen Tco3_p=sum(L.conw_p)
label variable Tco3_p "Number times correctly pessimistic objective nominal income + wealth"
bys pid: gen Tco3_s=sum(L.conw_s)
label variable Tco3_s "Number times correctly same objective nominal income + wealth"
egen Tco3=rsum(Tco3_o Tco3_p Tco3_s)
label variable Tco3 "Number times correct objective nominal income + wealth"
gen CRo3_o=Tco3_o/t
label variable CRo3_o "Number times correctly optimistic / time in panel objective nominal income + wealth"
gen CRo3_p=Tco3_p/t
label variable CRo3_p "Number times correctly pessimistic / time in panel objective nominal income + wealth"
gen CRo3_s=Tco3_s/t
label variable CRo3_s "Number times correctly same / time in panel objective nominal income + wealth"
gen CRo3=Tco3/t
label variable CRo3 "Number times correct / time in panel objective nominal income + wealth"
*35. number of times correct in forecast and rate - based upon objective outcome real income + wealth*
bys pid: gen Tco4_o=sum(L.corw_o)
label variable Tco4_o "Number times correctly optimistic objective real income + wealth"
bys pid: gen Tco4_p=sum(L.corw_p)
label variable Tco4_p "Number times correctly pessimistic objective real income + wealth"
bys pid: gen Tco4_s=sum(L.corw_s)
label variable Tco4_s "Number times correctly same objective real income + wealth"
egen Tco4=rsum(Tco4_o Tco4_p Tco4_s)
label variable Tco4 "Number times correct objective real income + wealth"
gen CRo4_o=Tco4_o/t
label variable CRo4_o "Number times correctly optimistic / time in panel objective real income + wealth"
gen CRo4_p=Tco4_p/t
label variable CRo4_p "Number times correctly pessimistic / time in panel objective real income + wealth"
gen CRo4_s=Tco4_s/t
label variable CRo4_s "Number times correctly same / time in panel objective real income + wealth"
gen CRo4=Tco4/t
label variable CRo4 "Number times correct / time in panel objective real income + wealth"
*36. number of times incorrect in forecast and rate - based upon objective outcome nominal income*
bys pid: gen Tico1_o=sum(L.icony_o)
label variable Tico1_o "Number times incorrectly optimistic objective nominal income"
bys pid: gen Tico1_p=sum(L.icony_p)
label variable Tico1_p "Number times incorrectly pessimistic objective nominal income"
bys pid: gen Tico1_s=sum(L.icony_s)
label variable Tico1_s "Number times incorrectly same objective nominal income"
egen Tico1=rsum(Tico1_o Tico1_p Tico1_s)
label variable Tco1 "Number times incorrect objective nominal income"
gen CRio1_o=Tico1_o/t
label variable CRio1_o "Number times incorrectly optimistic / time in panel objective nominal income"
gen CRio1_p=Tico1_p/t
label variable CRio1_p "Number times incorrectly pessimistic / time in panel objective nominal income"
gen CRio1_s=Tico1_s/t
label variable CRio1_s "Number times incorrectly same / time in panel objective nominal income"
gen CRio1=Tico1/t
label variable CRio1 "Number times incorrect / time in panel objective nominal income"
*37. number of times incorrect in forecast and rate - based upon objective outcome real income*
bys pid: gen Tico2_o=sum(L.icory_o)
label variable Tico2_o "Number times incorrectly optimistic objective real income"
bys pid: gen Tico2_p=sum(L.icory_p)
label variable Tico2_p "Number times incorrectly pessimistic objective real income"
bys pid: gen Tico2_s=sum(L.icory_s)
label variable Tico2_s "Number times incorrectly same objective real income"
egen Tico2=rsum(Tico2_o Tico2_p Tico2_s)
label variable Tico2 "Number times incorrect objective real income"
gen CRio2_o=Tico2_o/t
label variable CRio2_o "Number times incorrectly optimistic / time in panel objective real income"
gen CRio2_p=Tico2_p/t
label variable CRio2_p "Number times incorrectly pessimistic / time in panel objective real income"
gen CRio2_s=Tico2_s/t
label variable CRio2_s "Number times incorrectly same / time in panel objective real income"
gen CRio2=Tico2/t
label variable CRio2 "Number times incorrect / time in panel objective real income"
*38. number of times incorrect in forecast and rate - based upon objective outcome nominal income + wealth*
bys pid: gen Tico3_o=sum(L.iconw_o)
label variable Tico3_o "Number times incorrectly optimistic objective nominal income + wealth"
bys pid: gen Tico3_p=sum(L.iconw_p)
label variable Tico3_p "Number times incorrectly pessimistic objective nominal income + wealth"
bys pid: gen Tico3_s=sum(L.iconw_s)
label variable Tico3_s "Number times incorrectly same objective nominal income + wealth"
egen Tico3=rsum(Tico3_o Tico3_p Tico3_s)
label variable Tico3 "Number times incorrect objective nominal income + wealth"
gen CRio3_o=Tico3_o/t
label variable CRio3_o "Number times incorrectly optimistic / time in panel objective nominal income + wealth"
gen CRio3_p=Tico3_p/t
label variable CRio3_p "Number times incorrectly pessimistic / time in panel objective nominal income + wealth"
gen CRio3_s=Tico3_s/t
label variable CRio3_s "Number times incorrectly same / time in panel objective nominal income + wealth"
gen CRio3=Tico3/t
label variable CRio3 "Number times incorrect / time in panel objective nominal income + wealth"
*39. number of times incorrect in forecast and rate - based upon objective outcome real income + wealth*
bys pid: gen Tico4_o=sum(L.icorw_o)
label variable Tico4_o "Number times incorrectly optimistic objective real income + wealth"
bys pid: gen Tico4_p=sum(L.icorw_p)
label variable Tico4_p "Number times incorrectly pessimistic objective real income + wealth"
bys pid: gen Tico4_s=sum(L.icorw_s)
label variable Tico4_s "Number times incorrectly same objective real income + wealth"
egen Tico4=rsum(Tico4_o Tico4_p Tico4_s)
label variable Tico4 "Number times incorrect objective real income + wealth"
gen CRio4_o=Tico4_o/t
label variable CRio4_o "Number times incorrectly optimistic / time in panel objective real income + wealth"
gen CRio4_p=Tico4_p/t
label variable CRio4_p "Number times incorrectly pessimistic / time in panel objective real income + wealth"
gen CRio4_s=Tco4_s/t
label variable CRio4_s "Number times incorrectly same / time in panel objective real income + wealth"
gen CRio4=Tico4/t
label variable CRio4 "Number times incorrect / time in panel objective real income + wealth"
*40. recoding of problems affecting interview*
recode iv6a -9 -7 . 2 =0
recode iv6b -9 -7 . 2 =0
recode iv6c -9 -7 . 2 =0
recode iv6d -9 -7 . 2 =0
recode iv6e -9 -7 . 2 =0
recode iv6f -9 -7 . 2 =0
gen totprob=iv6a+iv6b+iv6c+iv6d+iv6e+iv6f
replace totprob=2 if totprob>2
label variable totprob "total number of problems affecting interview"
*41. whether interview seen latest payslip*
gen seepay=0
recode seepay 0=1 if payslp==1
label variable seepay "1=interviewer saw latest pay slip, 0=otherwise"
*42. coding off ghq questions*
gen capdec=0
recode capdec 0=1 if ghqd==1
label variable capdec "1=more capable of making decisions than usual, 0=otherwise"
gen noprob=0
recode noprob 0=1 if ghqf==1
label variable noprob "1=no problems in overcoming difficulties, 0=otherwise"
gen abprob=0
recode abprob 0=1 if ghqh==1
label variable abprob "1=able to face problems more than usual, 0=otherwise"
gen loscon=0
recode loscon 0=1 if ghqj==1
label variable loscon "1=not losing confidence at all, 0=otherwise"
*43. recode whether respondent alone when answering household finance section*
recode ivfa -9 -8 -7 . =0
*44. cooperation of respondent in interview*
gen coop=0
recode coop 0=1 if iv4==1
label variable coop "1=cooperation of respondent in interview very good, 0=otherwise"
*45. whether others present during interview*
recode iv1 -9 -7 2 . = 0
*46. job satisfaction*
drop jbsat
gen jbsat=0
recode jbsat 0=1 if (jbsat4==1 & emp==1) | (jssat2==1 & semp==1)
recode jbsat 0=2 if (jbsat4==2 & emp==1) | (jssat2==2 & semp==1)
recode jbsat 0=3 if (jbsat4==3 & emp==1) | (jssat2==3 & semp==1)
recode jbsat 0=4 if (jbsat4==4 & emp==1) | (jssat2==4 & semp==1)
recode jbsat 0=5 if (jbsat4==5 & emp==1) | (jssat2==5 & semp==1)
recode jbsat 0=6 if (jbsat4==6 & emp==1) | (jssat2==6 & semp==1)
recode jbsat 0=7 if (jbsat4==7 & emp==1) | (jssat2==7 & semp==1)
label variable jbsat "job security; 0=not emp or semp, 1=not satis at all,...,7=completely sat"
*47. map in BIG5 personality traits*
sort pid
merge pid using big5.dta
drop if _merge==2 /*1=missing BIG5 info*/
/*missing BIG5 indicator*/
gen nobig5=0
recode nobig5 0=1 if _merge==1
label variable nobig5 "1=information on BIG5 missing, 0=otherwise"
/*standardise BIG5 0/1 mean/sd*/
egen big5a_2005=std(big5a) if _merge==3
egen big5c_2005=std(big5c) if _merge==3
egen big5e_2005=std(big5e) if _merge==3
egen big5n_2005=std(big5n) if _merge==3
egen big5o_2005=std(big5o) if _merge==3
drop big5a big5c big5e big5n big5o
rename big5a_2005 big5a
label variable big5a "BIG5 - assertation"
rename big5c_2005 big5c
label variable big5c "BIG5 - conscientiousness"
rename big5e_2005 big5e
label variable big5e "BIG5 - extraversion"
rename big5n_2005 big5n
label variable big5n "BIG5 - neuroticism"
rename big5o_2005 big5o
label variable big5o "BIG5 - openness to experience"
drop _merge
drop if nobig5==1 /*drop those with no BIG5 info*/
*48. length of interview*
gen hours=ivfoih-ivsoih /*create hours*/
replace hours=0 if hours<0 & ivfoih==-9 /*recode negative hour length interview to zero if missing end hours*/
recode hours -23=1 /*denotes start time 11pm end time midnight*/
recode hours -22=2 /*denotes start time 10pm end time midnight, or start time 11pm end time 1am*/
recode hours -21=3 /*denotes start time 10pm end time 1am*/
replace hours=0 if ivsoih==20 & ivfoih==8 & hours==-12 /*denotes start time 8pm (24hrs) end time 8pm*/
replace hours=0 if ivsoih==15 & ivfoih==3 & hours==-12 /*denotes start time 3pm (24hrs) end time 3pm*/
replace hours=0 if ivsoih==19 & ivfoih==7 & hours==-12 /*denotes start time 7pm (24hrs) end time 7pm*/
replace hours=1 if ivsoih==15 & ivfoih==4 & hours==-11 /*denotes start time 3pm (24hrs) end time 4pm*/
replace hours=1 if ivsoih==21 & ivfoih==10 & hours==-11 /*denotes start time 9pm (24hrs) end time 10pm*/
replace hours=1 if ivsoih==13 & ivfoih==2 & hours==-11 /*denotes start time 1pm (24hrs) end time 2pm*/
replace hours=1 if ivsoih==12 & ivfoih==1 & hours==-11 /*denotes start time 12pm (24hrs) end time 1pm*/
replace hours=1 if ivsoih==18 & ivfoih==7 & hours==-11 /*denotes start time 6pm (24hrs) end time 7pm*/
replace hours=1 if ivsoih==15 & ivfoih==4 & hours==-11 /*denotes start time 3pm (24hrs) end time 4pm*/
replace hours=1 if ivsoih==19 & ivfoih==8 & hours==-11 /*denotes start time 7pm (24hrs) end time 8pm*/
replace hours=1 if ivsoih==20 & ivfoih==9 & hours==-11 /*denotes start time 8pm (24hrs) end time 9pm*/
replace hours=2 if ivsoih==20 & ivfoih==10 & hours==-10 /*denotes start time 8pm (24hrs) end time 10pm*/
replace hours=ivsoih-ivfoih if hours<0 /*switch hours around for funnies*/
gen mins=ivfoim-ivsoim /*create minutes*/
gen ilength=hours*60  /*translate hours variable to minutes*/
replace ilength=mins if (ilength==0 | ilength>360) & mins>0
replace ilength=60 if ilength==780 /*denotes start time either 6pm or 8pm end time either 19 or 21 (24hrs)*/
replace ilength=360 if ilength==540 /*denotes start time either 19 or 20 (24hrs) end time either 10pm or 11pm*/
recode ilength 420 480 = 360 /*top code to 360 minutes i.e. 3 hours*/
replace ilength=ivsoim-ivfoim if ilength==0 & ivfoim~=-9 & ivsoim~=-9 /*switch minutes around for funnies*/
label variable ilength "length of interview in minutes"
*49. merge in number of don't know responses*
/*install findname*/
sort pid year
merge pid year using "all variables.dta"
keep if _merge==3
drop _merge

#delimit;
keep pid year hoh expind* age sex a_* nkids marr white black asian deg ohigh alev olev othed emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2
region year fisitx fisitc ch_* *_o *_p *_s rg* yr3-yr18 Tcs* CR* iv6* seepay capdec noprob abprob loscon ivfa coop iv1 big5* ilength cdont csame totprob jbsat chivid 
ue_all lue trend opt pess same L* intopt intpess intsame *real_* *nom_* cfin* jbopps mgxty* lmgnew lpenadv pppen penadd xpfood xpleis cdb* move jbsat* y_up y_down ex_up ex_down
cd*new ncdur1 ncdur2 *_app age* doby* hhsize nch* cd*cst tsp_dur* ltsp_dur* nhprobs lreal_hy;

#delimit cr
sort pid
save "U:\expectations\nomeans.dta", replace

*50. create mundlaks*
#delimit;
collapse (mean) CR* Tcs* jbopps mgxty* lmgnew lpenadv pppen penadd xpfood xpleis cdb* cd*new move jbsat* y_up y_down ex_up ex_down 
ncdur1 ncdur2 *_app age* doby* hhsize nch* cd*cst tsp_dur* ltsp_dur* nhprobs lreal_hy, by(pid);
#delimit cr
foreach x of var * { 
rename `x' M`x'
} 
rename Mpid pid
sort pid
save "U:\expectations\mundlaks1.dta", replace
use "U:\expectations\nomeans.dta", clear
#delimit;
collapse (mean) expind* age a_* nkids marr deg ohigh alev olev othed emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2
fisitx fisitc ch_* *_o *_p *_s iv6* seepay capdec noprob abprob loscon ivfa coop iv1 big5* ilength cdont csame totprob jbsat chivid 
ue_all lue opt pess same L* *real_* *nom_* cfin*, by(pid);
#delimit cr
foreach x of var * { 
rename `x' M`x'
} 
rename Mpid pid
sort pid
save "U:\expectations\mundlaks2.dta", replace

*51. Map mundlaks into main data*
use "U:\expectations\nomeans.dta", clear
merge pid using "U:\expectations\mundlaks1.dta"
drop if _merge~=3
drop _merge
sort pid
merge pid using "U:\expectations\mundlaks2.dta"
drop if _merge~=3
drop _merge

save "U:\expectations\exp_bal_data.dta", replace

cd "U:\expectations\"
log using variables.log, replace
#delimit;
desc pid year hoh expind* age sex a_* nkids marr white black asian deg ohigh alev olev othed emp semp unemp ownor mort rentc llab lnlab lsaved lwealth 
hlghq2 region year fisitx fisitc ch_* rg* yr3-yr18 Tcs* CR* iv6* seepay capdec noprob abprob loscon ivfa coop iv1 big5* ilength cdont 
csame totprob jbsat chivid ue_all lue trend opt pess same L* intopt intpess intsame *real_* *nom_* cfin* jbopps mgxty* lmgnew lpenadv pppen penadd 
move jbsat* y_up y_down ex_up ex_down c*_o c*_p c*_s ic*_o ic*_p ic*_s xpfood xpleis cdb* cd*new ncdur1 ncdur2 h_app el_app age* doby* hhsize nch* cd*cst 
tsp_dur* ltsp_dur* nhprobs M*;
log close;
#delimit cr

*set globals*
global varlist "expind1 expind2"
global X a_* sex nkids marr white black asian deg ohigh alev olev othed emp semp unemp ownor mort rentc llab lnlab lsaved lwealth
global Z_split a_* sex deg ohigh alev olev othed CRs iv6* seepay capdec noprob abprob loscon ivfa coop iv1 big5* ilength cdont csame totprob jbsat chivid hlghq2

*********************************************************************************************************************************
*B. GET READY FOR STAT-TRANSFER TO GAUSS
cd "U:\expectations\"
use "U:\expectations\exp_bal_data.dta", clear
xtset pid year

*create nominal income change & errors
recode fisitc 3=1 1=2 2=0
g onom_y=0 if ch_ny<0
replace onom_y=1 if ch_ny==0
replace onom_y=2 if ch_ny>0
g error1=Lexp-fisitc
g error2=Lexp-onom_y

*create running count number of correct times - subjective
bys pid: gen nc_opt=sum(cs_o)
bys pid: gen nc_pes=sum(cs_p)
bys pid: gen nc_sam=sum(cs_s)
egen nc_all=rowtotal(nc_opt nc_pes nc_sam)

*create running count number of correct times - nominal income
bys pid: gen nc2_opt=sum(cony_o)
bys pid: gen nc2_pes=sum(cony_p)
bys pid: gen nc2_sam=sum(cony_s)
egen nc2_all=rowtotal(nc2_opt nc2_pes nc2_sam)

*recode sparse educational categories
recode deg 0=1 if ohigh==1
recode olev 0=1 if othed==1

*rescale interview length
replace ilength=ilength/100

*rename dependent variable
ren expind1 expect

keep pid year expect a_* sex deg alev olev nkids marr white emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2 jbsat ue_all y_up y_down ex_up ex_down trend nc_* nc2_* big5* chivid totprob ivfa ilength fisitc intopt intpess

**# Bookmark #1
*create means
global X "a_1830 a_3140 a_4150 deg alev olev nkids marr emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2 jbsat ue_all y_up y_down ex_up ex_down nc_opt nc_pes nc_sam nc_all nc2_opt nc2_pes nc2_sam nc2_all big5a big5c big5e big5n big5o chivid totprob ivfa ilength"

foreach y of global X  {
bys pid: egen M`y'=mean(`y')
}

global X sex white a_* deg alev olev nkids marr emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2 jbsat ue_all y_up y_down ex_up ex_down
global X2 a_* deg alev olev nkids marr emp semp unemp ownor mort rentc llab lnlab lsaved lwealth hlghq2 jbsat ue_all y_up y_down ex_up ex_down
global meansall Ma_* Mdeg Malev Molev Mnkids Mmarr Memp Msemp Munemp Mownor Mmort Mrentc Mllab Mlnlab Mlsaved Mlwealth Mhlghq2 Mjbsat Mue_all 
global means Mllab Mlnlab Mlsaved Mlwealth
global Z nc_all nc2_all big5a big5c big5e big5n big5o chivid totprob ivfa ilength

tab year, gen(yr)

*data for gauss
cd "U:\Expectations\JMCB revision\gauss\"
keep expect pid year $X Mllab Mlnlab Mlsaved Mlwealth $Z yr* year fisitc trend* intopt intpes
save "exp_bal_data_V4.dta", replace

*AT THIS POINT NEED TO CONVERT TO GAUSS DATA FILE (E.G. USING STATTRANSFER AND THEN RUN JMCB_GAUSSCODE_2023.E)
*******************************************************************************************************************

*ONCE GAUSS HAS FINISHED EXECUTING NEED TO TRANSFER GAUSS FE_DAT.SHOCK.DAT FILE TO STATA DATA FILE
*Subjective realisation - NC_ALL
use "U:\Expectations\JMCB revision\gauss\Mark code 21st June 2022\FE_dat_shock.dta", clear 
rename *, lower
g year=1992
replace year=1993 if yr2==1
replace year=1994 if yr3==1
replace year=1995 if yr4==1
replace year=1996 if yr5==1
replace year=1997 if yr6==1
replace year=1998 if yr7==1
replace year=1999 if yr8==1
replace year=2000 if yr9==1
replace year=2001 if yr10==1
replace year=2002 if yr11==1
replace year=2003 if yr12==1
replace year=2004 if yr13==1
replace year=2005 if yr14==1
replace year=2006 if yr15==1
replace year=2007 if yr16==1
replace year=2008 if yr17==1

ren y_st_topc_re GMIOPC
*October 100 Halton draws - 'first stage'
g OP=(0.6024*a_1830)+(0.1719*a_3140)+(0.06711*a_4150)+(0.04528*sex)+(0.004413*deg)+(-0.3268*alev)+(-0.1184*olev)+(0.2505*y_up)+(0.2511*y_down)+(-0.2022*ex_up)+(0.2555*ex_down)+(0.08662*nkids)+(-0.09645*marr)+(-0.1601*white)+(-0.1654*emp)+(0.04943*semp)+(0.4247*unemp)+(-0.1397*ownor)+(0.009528*mort)+(-0.04466*rentc)+(-0.195*llab)+(-0.224*lnlab)+(-0.295*lsaved)+(-0.3003*lwealth)+(0.05622*jbsat)+(-0.2698*hlghq2)+(-0.02623*ue_all)+(0.09131*yr2)*(0.1892*yr3)+(0.2812*yr4)+(0.3349*yr5)+(0.3733*yr6)+(0.4815*yr7)+(0.4645*yr8)+(0.5186*yr9)+(0.4831*yr10)+(0.5158*yr11)+(0.6529*yr12)+(0.6213*yr13)+(0.662*yr14)+(0.5945*yr15)+(0.6572*yr16)+(0.1275*yr17)+(0.2788*opt_0)+(-0.2924*pess_0)+(0.2287*mllab)+(-0.1807*mlnlab)+(0.2451*mlsaved)+(-0.3305*mlwealth)-1.033-0.2149+0.7632+0.2993 /*panel - GMIOPC - no purging*/

*RE ordered probit
xtset id
xtoprobit expect a_* sex deg alev olev y_up y_down ex_up ex_down nkids marr white emp semp unemp ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all mllab mlnlab mlsaved mlwealth *_0 yr*, i(id) 
predict OP1, xb  /*panel - OP*/

g expind=expect
la variable expind "Financial Expectations"
la val expind expind
recode expind 0=-1 1=0 2=1

*FIGURE 1
twoway (histogram expind, discrete color(sunflowerlime) lcolor(gold)) ///
(kdensity OP1, lcolor(red) lpattern(dash) lwidth(thick)) ///
(kdensity OP, lcolor(green) lpattern(shortdash_dot) lwidth(thick)) ///
(kdensity GMIOPC, lcolor(blue) lwidth(thick)), ///
xlabel(-2(1)2) xtitle(, size(vsmall) margin(small) color(black)) xlabel(, labsize(vsmall)) ///
ytitle(Density) ytitle(, size(vsmall) margin(small) color(black)) ylabel(, labsize(vsmall)) ylabel(#10) ///
legend(on order(1 "Financial Expectations" 2 "Linear Prediction OP" 3 "Linear Prediction GMIOPC: y* only" 4 "Linear Prediction GMIOPC: full model") ///
cols(2) size(vsmall) color(black) box fcolor(none) lcolor(none) region(fcolor(none) lcolor(none)))

graph save "U:\Expectations\JMCB revision\gauss\Mark code 21st June 2022\Figure 2.gph", replace

cd "U:\Expectations\JMCB revision\"
g a=1
bys id year: gen b=sum(a)
drop if b==2

keep id year expind OP GMIOPC a_* sex llab mllab mlnlab mlsaved mlwealth llab lnlab lsaved lwealth *_0
ren a_* A_*
ren sex SEX
ren llab LLAB
sort id year
save subjective_Y.dta, replace

/*
*Nominal realisation - NC2_ALL
use "U:\Expectations\JMCB revision\gauss\Mark code 21st June 2022\FE_dat_shock_NC2.dta", clear 
rename *, lower
g year=1993
replace year=1994 if yr3==1
replace year=1995 if yr4==1
replace year=1996 if yr5==1
replace year=1997 if yr6==1
replace year=1998 if yr7==1
replace year=1999 if yr8==1
replace year=2000 if yr9==1
replace year=2001 if yr10==1
replace year=2002 if yr11==1
replace year=2003 if yr12==1
replace year=2004 if yr13==1
replace year=2005 if yr14==1
replace year=2006 if yr15==1
replace year=2007 if yr16==1
replace year=2008 if yr17==1

ren y_st_topc_re GMIOPC_nom /*panel*/

cd "U:\Expectations\JMCB revision\"
g a=1
bys id year: gen b=sum(a)
drop if b==2

keep id year GMIOPC_nom

sort id year
save nominal_Y.dta, replace
*/

*********************************************************************************************************************************

*C. EXPENDITURE MODELS
*JMCB revision expenditure
cd "U:\expectations\"
use "U:\expectations\exp_bal_data.dta", clear
egen id=group(pid)
*merge in predictions from first stage
sort id year
merge id year using "U:\Expectations\JMCB revision\subjective_Y.dta"
drop if _merge==2
drop _merge
*sort id year
*merge id year using "U:\Expectations\JMCB revision\nominal_Y.dta"
*drop if _merge==2
*drop _merge
*merge in purged probabilies
sort id year
merge id year using "U:\Expectations\JMCB revision\probabilities_purged.dta"
drop if _merge==2
drop _merge

egen s_GMIOPC=std(GMIOPC)
egen s_GMIOPC_nom=std(GMIOPC_nom)
pwcorr s_GMIOPC s_GMIOPC_nom, sig
twoway (kdensity s_GMIOPC, lcolor(red)) (kdensity s_GMIOPC_nom, lcolor(blue))
drop s_*

global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
*set initial conditions for dynamic models*/
sort pid year
bys pid: gen int_cd1new=cd1new[1]
bys pid: gen int_cd2new=cd2new[1]
bys pid: gen int_cd3new=cd3new[1]
bys pid: gen int_cd4new=cd4new[1]
bys pid: gen int_cd5new=cd5new[1]
bys pid: gen int_cd6new=cd6new[1]
bys pid: gen int_cd7new=cd7new[1]
bys pid: gen int_cd8new=cd8new[1]
bys pid: gen int_cd9new=cd9new[1]

*MODELS
*1.	System probits
*2.	Dynamic probits
*3.	Split by electronics, household appliances (as per Browning and Crossley)
*4.	Count model
*5.	£expenditure amounts (including food and leisure)

*rename Y_ST_TOP2 Y1_TOPCRE /*GMIOPC subjective*/
*rename Y_TOPC_R Y2_TOPCRE /*GMIOPC nominal*/

replace tsp_dur=. if year<1997
replace ltsp_dur=. if year<1997

cd "U:\Expectations\JMCB revision\second stage\"
save expenditure_KR_data_august2022.dta, replace

*merge in hid identifier
*Individual variables from source files #_INDRESP*
cd "U:\expectations\data\"
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid pid `w'hoh using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold ind_bhps_`w', replace
}
use ind_bhps_a, clear
append using ind_bhps_b
append using ind_bhps_c
append using ind_bhps_d
append using ind_bhps_e
append using ind_bhps_f
append using ind_bhps_g
append using ind_bhps_h
append using ind_bhps_i
append using ind_bhps_j
append using ind_bhps_k
append using ind_bhps_l
append using ind_bhps_m
append using ind_bhps_n
append using ind_bhps_o
append using ind_bhps_p
append using ind_bhps_q
append using ind_bhps_r
replace pid=id if wave==16 & pid==.
gen year=1990+wave
keep pid hid year
drop if year==1991
sort pid year
cd "U:\Expectations\JMCB revision\second stage\"
save ind_all_hid.dta, replace

use expenditure_KR_data_august2022.dta, clear
sort pid year
merge pid year using ind_all_hid.dta
drop if _merge==2
drop _merge

sort hid
bys hid year: egen s=sd(ltsp_dur)

keep if hoh==1

replace opt_0=intopt if opt_0==.
replace pess_0=intpess if pess_0==.
replace mllab=Mllab if mllab==.
replace mlnlab=Mlnlab if mlnlab==.
replace mlsaved=Mlsaved if mlsaved==.
replace mlwealth=Mlwealth if mlwealth==.

save expenditure_KR_data_august2022.dta, replace

*********************************************************************************************************************************
*C1. TABLE 7 panel CRE tobit static and dynamic models - SEs delta method
*****TYPES OF EXPENDITURE - BROWNING & CROSSLEY SPLIT INTO HOUSEHOLD APPLIANCES AND ELECTRONIC GOODS*****
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1
gen ltsp_dur_house=ltsp_dur if houseapp==1 
recode ltsp_dur_house .=0
replace ltsp_dur_house=. if year<1997
gen ltsp_dur_elec=ltsp_dur if electronics==1
recode ltsp_dur_elec .=0
replace ltsp_dur_elec=. if year<1997
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

replace expind=fisitx if expind==.

sort pid year
bys pid: gen int_am_ltsp_dur2=ltsp_dur2[1]
bys pid: gen int_am_ltsp_dur_elec=ltsp_dur_elec[6] if year>=1997
bys pid: gen int_am_ltsp_dur_house=ltsp_dur_house[6] if year>=1997
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[6] if year>=1997
bys pid: gen int_houseapp=houseapp[6] if year>=1997

*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}

drop m_doby*
global varlist "ltsp_dur2 ltsp_dur_elec ltsp_dur_house"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy

bys pid: gen nc_opt=sum(cs_o)
bys pid: gen nc_pes=sum(cs_p)
bys pid: gen nc_sam=sum(cs_s)
egen nc_all=rowtotal(nc_opt nc_pes nc_sam)

replace houseapp=. if ltsp_dur_house==.
replace electronics=. if ltsp_dur_elec==.

*standardise
egen s_expind=std(expind)
egen s_OP=std(GMIOPC)
egen s_GMIOPC=std(OP)
drop expind OP GMIOPC
renpfix s_

*MEs using scaling factor
log using "fullMEs table 7_PANEL A_C.log", replace
foreach y of global varlist  {
*PANEL A
desc `y' 
xttobit `y' $X m_* expind, i(pid) ll(0) re /*exogenous static*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1

desc `y' 
xttobit `y' int_am_`y' L.`y' $X m_* expind, i(pid) ll(0) re /*exogenous dynamic*/
mat ME2=(e(N_lc)/e(N))*e(b)
mat V2=(e(N_lc)/e(N))*e(V)
mat VAR2=vecdiag(e(V))
matmap VAR2 SE2, map(sqrt(@))
mat SE2=SE2*(e(N_lc)/e(N))
mat li ME2
mat li SE2

*PANEL B
desc `y' 
xttobit `y' $X m_* OP, i(pid) ll(0) re /*endogenous static*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1

desc `y' 
xttobit `y' int_am_`y' L.`y' $X m_* OP, i(pid) ll(0) re /*endogenous dynamic*/
mat ME2=(e(N_lc)/e(N))*e(b)
mat V2=(e(N_lc)/e(N))*e(V)
mat VAR2=vecdiag(e(V))
matmap VAR2 SE2, map(sqrt(@))
mat SE2=SE2*(e(N_lc)/e(N))
mat li ME2
mat li SE2

*PANEL C
desc `y' 
xttobit `y' $X m_* GMIOPC, i(pid) ll(0) re /*endogenous static*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1

desc `y' 
xttobit `y' int_am_`y' L.`y' $X m_* GMIOPC, i(pid) ll(0) re /*endogenous dynamic*/
mat ME2=(e(N_lc)/e(N))*e(b)
mat V2=(e(N_lc)/e(N))*e(V)
mat VAR2=vecdiag(e(V))
matmap VAR2 SE2, map(sqrt(@))
mat SE2=SE2*(e(N_lc)/e(N))
mat li ME2
mat li SE2
}
log close

/*
qui: xttobit ltsp_dur2 $X m_* expind, i(pid) ll(0) re
est store a_1
qui: xttobit ltsp_dur2 $X m_* OP, i(pid) ll(0) re
est store a_2
hausman a_2 a_1

qui: xttobit ltsp_dur_elec $X m_* expind, i(pid) ll(0) re
est store b_1
qui: xttobit ltsp_dur_elec $X m_* OP, i(pid) ll(0) re
est store b_2
hausman b_2 b_1

qui: xttobit ltsp_dur_house $X m_* expind, i(pid) ll(0) re
est store c_1
qui: xttobit ltsp_dur_house $X m_* OP, i(pid) ll(0) re
est store c_2
hausman c_2 c_1

qui: xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 $X m_* expind, i(pid) ll(0) re
est store d_1
qui: xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 $X m_* OP, i(pid) ll(0) re
est store d_2
hausman d_2 d_1

qui: xttobit ltsp_dur_elec int_am_ltsp_dur_elec L.ltsp_dur_elec $X m_* expind, i(pid) ll(0) re
est store e_1
qui: xttobit ltsp_dur_elec int_am_ltsp_dur_elec L.ltsp_dur_elec $X m_* OP, i(pid) ll(0) re
est store e_2
hausman e_2 e_1

qui: xttobit ltsp_dur_house int_am_ltsp_dur_house L.ltsp_dur_house $X m_* expind, i(pid) ll(0) re
est store f_1
qui: xttobit ltsp_dur_house int_am_ltsp_dur_house L.ltsp_dur_house $X m_* OP, i(pid) ll(0) re
est store f_2
hausman f_2 f_1
*/

*********************************************************************************************************************************
*C2. TABLE 8 panel CRE probit static and dynamic models - SEs delta method & KR method
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1 | cd13new==13
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   
replace houseapp=. if year<1997
replace electronics=. if year<1997
*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}
drop m_doby*
*create initial conditions
xtset pid year
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[1]
bys pid: gen int_houseapp=houseapp[1]
*bys pid: gen int_electronics=electronics[6] if year>=1997
*bys pid: gen int_houseapp=houseapp[6] if year>=1997
*create lags
g lag_anyp=L.anyp
g lag_electronics=L.electronics
g lag_houseapp=L.houseapp

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

recode expind 0=-1 1=0 2=1

replace expind=fisitx if expind==.

*standardise
egen s_expind=std(expind)
egen s_OP=std(GMIOPC)
egen s_GMIOPC=std(OP)
drop expind OP GMIOPC
renpfix s_

save expenditure_KR_data.dta, replace

*1. Exogenous expectations
use expenditure_KR_data.dta, clear
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"
log using "fullMEs table 8_panel A-C.log", replace
foreach y of global varlist {
xtlogit `y' $X expind, i(pid) re
margins, dydx($X expind)
xtlogit `y' int_`y' lag_`y' $X m_* expind, i(pid) re
margins, dydx(lag_`y' $X expind)
}
log close

*2. Krinsky & Robb - Static - OP model
use expenditure_KR_data.dta, clear
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy OP, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bOP bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X OP, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bOP[`i']*OP + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bOP[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using "table 8_panel B.log", append
desc `y'
quietly xtlogit `y' $X OP, i(pid) re
margins, dydx(OP)
*************************
sum me_Y1mean
log close
}

*3. Krinsky & Robb - Static - GMIOPC subjective
use expenditure_KR_data.dta, clear
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy GMIOPC, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bGMIOPC bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X GMIOPC, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bGMIOPC[`i']*GMIOPC + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bGMIOPC[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using "table 8_panel C.log", append
desc `y'
quietly xtlogit `y' $X GMIOPC, i(pid) re
margins, dydx(GMIOPC)
*************************
sum me_Y1mean
log close
}

*4. Krinsky & Robb - Dynamic - OP model
use expenditure_KR_data.dta, clear
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"
foreach y of global varlist  {
quietly xtlogit `y' int_`y' lag_`y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* OP, i(pid) re
matrix b = e(b)
matselrc b b, c(1/36)
matrix V = e(V)

drawnorm bint_`y' blag_`y' bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bm_age bm_age2 bm_age3 bm_age4 bm_hhsize bm_nch02 bm_nch34 bm_nch511 bm_nch1215 bm_nch1618 bm_nhprobs bm_emp bm_semp bm_unemp bm_lreal_hy bOP bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' int_`y' lag_`y' $X m_* OP, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bint_`y'[`i']*int_`y' + blag_`y'[`i']*lag_`y' + bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bm_age[`i']*m_age + bm_age2[`i']*m_age2 + bm_age3[`i']*m_age3 + bm_age4[`i']*m_age4 + bm_hhsize[`i']*m_hhsize + bm_nch02[`i']*m_nch02 + bm_nch34[`i']*m_nch34 + bm_nch511[`i']*m_nch511 + bm_nch1215[`i']*m_nch1215 + bm_nch1618[`i']*m_nch1618 + bm_nhprobs[`i']*m_nhprobs + bm_emp[`i']*m_emp + bm_semp[`i']*m_semp + bm_unemp[`i']*m_unemp + bm_lreal_hy[`i']*m_lreal_hy + bOP[`i']*OP + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bOP[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using "table 8_panel B_dynamic.log", append
desc `y'
quietly xtlogit `y' int_`y' lag_`y' $X m_* OP, i(pid) re
margins, dydx(OP)
*************************
sum me_Y1mean
log close
}

*5. Krinsky & Robb - Dynamic - GMIOPC subjective
use expenditure_KR_data.dta, clear
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"
foreach y of global varlist  {
quietly xtlogit `y' int_`y' lag_`y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* GMIOPC, i(pid) re
matrix b = e(b)
matselrc b b, c(1/36)
matrix V = e(V)

drawnorm bint_`y' blag_`y' bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bm_age bm_age2 bm_age3 bm_age4 bm_hhsize bm_nch02 bm_nch34 bm_nch511 bm_nch1215 bm_nch1618 bm_nhprobs bm_emp bm_semp bm_unemp bm_lreal_hy bGMIOPC bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' int_`y' lag_`y' $X m_* GMIOPC, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bint_`y'[`i']*int_`y' + blag_`y'[`i']*lag_`y' + bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bm_age[`i']*m_age + bm_age2[`i']*m_age2 + bm_age3[`i']*m_age3 + bm_age4[`i']*m_age4 + bm_hhsize[`i']*m_hhsize + bm_nch02[`i']*m_nch02 + bm_nch34[`i']*m_nch34 + bm_nch511[`i']*m_nch511 + bm_nch1215[`i']*m_nch1215 + bm_nch1618[`i']*m_nch1618 + bm_nhprobs[`i']*m_nhprobs + bm_emp[`i']*m_emp + bm_semp[`i']*m_semp + bm_unemp[`i']*m_unemp + bm_lreal_hy[`i']*m_lreal_hy + bGMIOPC[`i']*GMIOPC + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bGMIOPC[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using "table 8_panel C_dynamic.log", append
desc `y'
quietly xtlogit `y' int_`y' lag_`y' $X m_* GMIOPC, i(pid) re
margins, dydx(GMIOPC)
*************************
sum me_Y1mean
log close
}

*********************************************************************************************************************************
*C3. TABLE 9 panel CRE probit static models - SEs delta method & KR method
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1 | cd13new==13
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   
replace houseapp=. if year<1997
replace electronics=. if year<1997
*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}
drop m_doby*
*create initial conditions
xtset pid year
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[1]
bys pid: gen int_houseapp=houseapp[1]
*bys pid: gen int_electronics=electronics[6] if year>=1997
*bys pid: gen int_houseapp=houseapp[6] if year>=1997
*create lags
g lag_anyp=L.anyp
g lag_electronics=L.electronics
g lag_houseapp=L.houseapp

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

recode expind 0=-1 1=0 2=1

replace expind=fisitx if expind==.

*standardise
egen s_expind=std(expind)
egen s_OP=std(GMIOPC)
egen s_GMIOPC=std(OP)
drop expind OP GMIOPC
renpfix s_

save expenditure_KR_data.dta, replace

*1A. exogenous
global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
log using table_9full.log, replace
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy expind, i(pid) re
desc `y' 
margins, dydx(expind)
}
log close

*1B. Fitted value - OP model*
use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy OP, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bOP bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X OP, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bOP[`i']*OP + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bOP[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using table_9full.log, append
desc `y'
quietly xtlogit `y' $X OP, i(pid) re
margins, dydx(OP)
*************************
sum me_Y1mean
log close

use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
}

*1C. Fitted value - GMIOPC model*
use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy GMIOPC, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bGMIOPC bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X GMIOPC, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bGMIOPC[`i']*GMIOPC + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bGMIOPC[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using table_9full.log, append
desc `y'
quietly xtlogit `y' $X GMIOPC, i(pid) re
margins, dydx(GMIOPC)
*************************
sum me_Y1mean
log close

use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
}

/*SUB-SAMPLE BINARY MODELS NT=17,004*/
*2. TABLE 11 columns 10-13 (Satellite dish through to Mobile phone player NT=11,270) Type of expenditure - binary random effects logit*
*exogenous
use expenditure_KR_data.dta, clear
global varlist "cd10new cd11new cd12new cd13new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
*2A. exogenous
log using table9_sub.log, replace
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy expind, i(pid) re
margins, dydx(expind)
}
log close

*2B. Fitted value - OP model*
use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
global varlist "cd10new cd11new cd12new cd13new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy OP, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bOP bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X OP, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bOP[`i']*OP + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bOP[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using table_9sub.log, append
desc `y'
quietly xtlogit `y' $X OP, i(pid) re
margins, dydx(OP)
*************************
sum me_Y1mean
log close

use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
}

*2C. Fitted value - GMIOPC model*
use expenditure_KR_data.dta, clear

generate one1 = 1
generate one2 = 1
global varlist "cd10new cd11new cd12new cd13new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
foreach y of global varlist  {
quietly xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy GMIOPC, i(pid) re
matrix b = e(b)
matselrc b b, c(1/19)
matrix V = e(V)

drawnorm bage bage2 bage3 bage4 bdoby bdoby2 bhhsize bnch02 bnch34 bnch511 bnch1215 bnch1618 bnhprobs bemp bsemp bunemp blreal_hy bGMIOPC bone1, n(1000) means(b) cov(V) seed(12345) clear

save KRdata_`y', replace

* Krinsky-Robb
use expenditure_KR_data.dta, clear
quietly xtlogit `y' $X GMIOPC, i(pid) re

merge 1:1 _n using KRdata_`y'

generate one1 = 1
generate one2 = 1
generate xbeta = .
generate phat = .
generate phatmean = .
generate me_Y1 = .
generate me_Y1mean = .

 forvalues i = 1/1000 {
	quietly replace xbeta = bage[`i']*age + bage2[`i']*age2 + bage3[`i']*age3 + bage4[`i']*age4 + bdoby[`i']*doby + bdoby2[`i']*doby2 + bhhsize[`i']*hhsize + bnch02[`i']*nch02 + bnch34[`i']*nch34 + bnch511[`i']*nch511 + bnch1215[`i']*nch1215 + bnch1618[`i']*nch1618 + bnhprobs[`i']*nhprobs + bemp[`i']*emp + bsemp[`i']*semp + bunemp[`i']*unemp + blreal_hy[`i']*lreal_hy + bGMIOPC[`i']*GMIOPC + bone1[`i']
	quietly replace phat = 1/(1 + exp(-xbeta))
	quietly summarize phat, meanonly
	quietly replace phatmean = r(mean) if _n == `i'	
	
	quietly replace me_Y1 = (bGMIOPC[`i'])*phat*(1 - phat)
	quietly summarize me_Y1, meanonly
	quietly replace me_Y1mean = r(mean) if _n == `i'
}

log using table_9sub.log, append
desc `y'
quietly xtlogit `y' $X GMIOPC, i(pid) re
margins, dydx(GMIOPC)
*************************
sum me_Y1mean
log close

use expenditure_KR_data.dta, clear
generate one1 = 1
generate one2 = 1
}

*********************************************************************************************************************************
*D1. Comparison of expections (exogenous & endogenous) to income during recessionary periods
*********************************************************************************************************************************
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1
gen ltsp_dur_house=ltsp_dur if houseapp==1 
recode ltsp_dur_house .=0
replace ltsp_dur_house=. if year<1997
gen ltsp_dur_elec=ltsp_dur if electronics==1
recode ltsp_dur_elec .=0
replace ltsp_dur_elec=. if year<1997
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

replace expind=fisitx if expind==.

sort pid year
bys pid: gen int_am_ltsp_dur2=ltsp_dur2[1]
bys pid: gen int_am_ltsp_dur_elec=ltsp_dur_elec[6] if year>=1997
bys pid: gen int_am_ltsp_dur_house=ltsp_dur_house[6] if year>=1997
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[6] if year>=1997
bys pid: gen int_houseapp=houseapp[6] if year>=1997

*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}

drop m_doby*
global varlist "ltsp_dur2 ltsp_dur_elec ltsp_dur_house"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy

bys pid: gen nc_opt=sum(cs_o)
bys pid: gen nc_pes=sum(cs_p)
bys pid: gen nc_sam=sum(cs_s)
egen nc_all=rowtotal(nc_opt nc_pes nc_sam)

*income & expenditure growth rates
xtset pid year
bys pid: gen d_exp=D.ltsp_dur2
g growth_inc=(D.lreal_hy/lreal_hy)*100
bys year: egen mean_growth_rate_inc=mean(growth_inc)
xtset pid year
g growth_tsp=(D.ltsp_dur2/ltsp_dur2)*100
recode growth_tsp .=0 if year~=1992
g growth_tsp_elec=(D.ltsp_dur_elec/ltsp_dur_elec)*100
recode growth_tsp_elec .=0 if ltsp_dur_elec~=.
g growth_tsp_house=(D.ltsp_dur_house/ltsp_dur_house)*100
recode growth_tsp_house .=0 if ltsp_dur_house~=.
bys year: egen mean_growth_rate_tsp=mean(growth_tsp)
twoway (line mean_growth_rate_inc year, sort lcolor(blue) lwidth(medthick)) (line mean_growth_rate_tsp year, sort yaxis(2) ///
 lcolor(red) lwidth(medthick)), xtitle("") xlabel(1992(1)2008, labsize(small) angle(forty_five))

*income - mean, median & variation
bys year: egen mean_inc=mean(lreal_hy)
bys year: egen median_inc=median(lreal_hy)
bys year: egen sd_inc=sd(lreal_hy)
xtset pid year
bys pid: gen d_inc=D.lreal_hy
bys year: egen diff_inc=mean(d_inc)
bys year: egen p10=pctile(lreal_hy), p(10)
bys year: egen p90=pctile(lreal_hy), p(90)
g p9010=p90-p10

twoway (line diff_inc year, sort lcolor(blue) lwidth(medthick)) (dropline p9010 year, sort yaxis(2) ///
mcolor(red) lcolor(red)), xtitle("") xlabel(1992(1)2008, labsize(small) angle(forty_five))
graph save "income.gph", replace

*expenditure as a proportion of income
g real_hy=exp(lreal_hy)
recode real_hy 1=0
g ex_inc=(tsp_dur2)/(real_hy)

*negative growth in income, expenditure and expenditure to income ratio
g neg_inc=0
recode neg_inc 0=1 if d_inc<0
bys year: egen n_inc=mean(neg_inc)
g neg_tsp=0
recode neg_tsp 0=1 if d_exp<0
bys year: egen n_tsp=mean(neg_tsp)
xtset pid year
g diff_ex_inc=D.ex_inc
g neg_ex_inc=0
recode neg_ex_inc 0=1 if diff_ex_inc<0
bys year: egen n_ex_inc=mean(neg_ex_inc)
twoway (bar n_ex_inc year, sort) (bar n_tsp year) (bar n_inc year), xlabel(1993(1)2008)

*expectations - mean, median & variation
bys year: egen mean_exp=mean(expind)
bys year: egen sd_exp=sd(expind)
xtset pid year
bys pid: gen d_exp=D.expind
bys year: egen diff_exp=mean(d_exp)
twoway (line mean_exp year, sort lcolor(blue) lwidth(medthick)) (dropline diff_exp year, sort yaxis(2) ///
mcolor(red) lcolor(red)), xtitle("") xlabel(1992(1)2008, labsize(small) angle(forty_five))
graph save "expect.gph", replace
*expectations: endogenous GMIOPC - mean, median & variation
bys year: egen mean_gmiopc=mean(GMIOPC)
bys year: egen sd_gmiopc=sd(GMIOPC)
xtset pid year
bys pid: gen d_gmiopc=D.GMIOPC
bys year: egen diff_gmiopc=mean(d_gmiopc)
twoway (line mean_gmiopc year, sort lcolor(blue) lwidth(medthick)) (dropline diff_gmiopc year, sort yaxis(2) ///
mcolor(red) lcolor(red)), xtitle("") xlabel(1992(1)2008, labsize(small) angle(forty_five))
graph save "expect_end.gph", replace
*expenditure - mean, median & variation
bys year: egen mean_spend=mean(ltsp_dur2)
bys year: egen median_spend=median(ltsp_dur2)
bys year: egen sd_spend=sd(ltsp_dur2)
xtset pid year
bys pid: gen d_spend=D.ltsp_dur2
bys year: egen diff_spend=mean(d_spend)
twoway (line mean_spend year, sort lcolor(blue) lwidth(medthick)) (dropline diff_spend year, sort yaxis(2) ///
mcolor(red) lcolor(red)), xtitle("") xlabel(1992(1)2008, labsize(small) angle(forty_five))
graph save "spend.gph", replace
graph combine "income" "spend" "expect" "expect_end"
graph save "recession.gph", replace

xtset pid year
*tobit models - proportion of model pseudo r-squared explained by expectations and income compared to constant only model
log using "expenditure explained.log", replace
*exogenous expectations
xttobit ltsp_dur2 if year>=1997, ll(0)
g noX=e(ll)
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp, ll(0) re
g base_controls=1-(e(ll)/noX)
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp lreal_hy, ll(0) re
g inc_control=1-(e(ll)/noX)
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp expind, ll(0) re
g exp_control=1-(e(ll)/noX)
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp lreal_hy expind, ll(0) re
g all_control=1-(e(ll)/noX)
*endogenous expectations GMIOPC
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp GMIOPC, ll(0) re
g exp_control_end=1-(e(ll)/noX)
xttobit ltsp_dur2 int_am_ltsp_dur2 L.ltsp_dur2 age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp m_age-m_unemp c.trend##c.trend lreal_hy GMIOPC, ll(0) re
g all_control_end=1-(e(ll)/noX)
*proportion explained by income, expenditure and all X's
g inc_explained=abs((inc_control-base_controls)/base_controls)*100
g exp_explained=abs((exp_control-base_controls)/base_controls)*100
g exp_explained_end=abs((exp_control_end-base_controls)/base_controls)*100
g all_explained=abs((all_control-base_controls)/base_controls)*100
g all_explained_end=abs((all_control_end-base_controls)/base_controls)*100
sum *_explained*
log close

drop *_explained* *_control* noX

xtset pid year
*linear RE models of growth rate in expenditure during recessionary years - proportion R2 explained by expectations and income
log using "expenditure changes explained.log", replace
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g base_controls=e(r2_o)
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g inc_control=e(r2_o)
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.expind if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control=e(r2_o)
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.expind if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g all_control=e(r2_o)
*endogenous expectations GMIOPC
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.GMIOPC if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control_end=e(r2_o)
xtreg growth_tsp age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.GMIOPC if year<=1993 | year==1998 | year==2001 | year>=2006, i(pid) re
g all_control_end=e(r2_o)
*proportion explained by income, expenditure and all X's
g inc_explained=abs((inc_control-base_controls)/base_controls)*100
g exp_explained=abs((exp_control-base_controls)/base_controls)*100
g exp_explained_end=abs((exp_control_end-base_controls)/base_controls)*100
g all_explained=abs((all_control-base_controls)/base_controls)*100
g all_explained_end=abs((all_control_end-base_controls)/base_controls)*100
sum *_explained*
log close

drop *_explained* *_control*

xtset pid year
*linear RE models of growth rate in electronics expenditure during recessionary years - proportion R2 explained by expectations and income
log using "electronics expenditure changes explained.log", replace
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp if year==1998 | year==2001 | year>=2006, i(pid) re
g base_controls=e(r2_o)
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y if year==1998 | year==2001 | year>=2006, i(pid) re
g inc_control=e(r2_o)
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.expind if year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control=e(r2_o)
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.expind if year==1998 | year==2001 | year>=2006, i(pid) re
g all_control=e(r2_o)
*endogenous expectations GMIOPC
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.GMIOPC if year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control_end=e(r2_o)
xtreg growth_tsp_elec age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.GMIOPC if year==1998 | year==2001 | year>=2006, i(pid) re
g all_control_end=e(r2_o)
*proportion explained by income, expenditure and all X's
g inc_explained=abs((inc_control-base_controls)/base_controls)*100
g exp_explained=abs((exp_control-base_controls)/base_controls)*100
g exp_explained_end=abs((exp_control_end-base_controls)/base_controls)*100
g all_explained=abs((all_control-base_controls)/base_controls)*100
g all_explained_end=abs((all_control_end-base_controls)/base_controls)*100
sum *_explained*
log close

drop *_explained* *_control*

xtset pid year
*linear RE models of growth rate in household appliances expenditure during recessionary years - proportion R2 explained by expectations and income
log using "household appliances expenditure changes explained.log", replace
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp if year==1998 | year==2001 | year>=2006, i(pid) re
g base_controls=e(r2_o)
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y if year==1998 | year==2001 | year>=2006, i(pid) re
g inc_control=e(r2_o)
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.expind if year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control=e(r2_o)
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.expind if year==1998 | year==2001 | year>=2006, i(pid) re
g all_control=e(r2_o)
*endogenous expectations GMIOPC
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.GMIOPC if year==1998 | year==2001 | year>=2006, i(pid) re
g exp_control_end=e(r2_o)
xtreg growth_tsp_house age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp c.year#c.lreal_y c.year#c.GMIOPC if year==1998 | year==2001 | year>=2006, i(pid) re
g all_control_end=e(r2_o)
*proportion explained by income, expenditure and all X's
g inc_explained=abs((inc_control-base_controls)/base_controls)*100
g exp_explained=abs((exp_control-base_controls)/base_controls)*100
g exp_explained_end=abs((exp_control_end-base_controls)/base_controls)*100
g all_explained=abs((all_control-base_controls)/base_controls)*100
g all_explained_end=abs((all_control_end-base_controls)/base_controls)*100
sum *_explained*
log close

*********************************************************************************************************************************
*D2 IV tests
*********************************************************************************************************************************
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1
gen ltsp_dur_house=ltsp_dur if houseapp==1 
recode ltsp_dur_house .=0
replace ltsp_dur_house=. if year<1997
gen ltsp_dur_elec=ltsp_dur if electronics==1
recode ltsp_dur_elec .=0
replace ltsp_dur_elec=. if year<1997
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

replace expind=fisitx if expind==.

sort pid year
bys pid: gen int_am_ltsp_dur2=ltsp_dur2[1]
bys pid: gen int_am_ltsp_dur_elec=ltsp_dur_elec[6] if year>=1997
bys pid: gen int_am_ltsp_dur_house=ltsp_dur_house[6] if year>=1997
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[6] if year>=1997
bys pid: gen int_houseapp=houseapp[6] if year>=1997

*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}

drop m_doby*
global varlist "ltsp_dur2 ltsp_dur_elec ltsp_dur_house"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy

bys pid: gen nc_opt=sum(cs_o)
bys pid: gen nc_pes=sum(cs_p)
bys pid: gen nc_sam=sum(cs_s)
egen nc_all=rowtotal(nc_opt nc_pes nc_sam)

*D2.1 Instrument validity tests
xtset pid year
global IV a_1830 a_3140 a_4150 sex deg alev olev big5a big5o big5n big5e big5c nc_all chivid totprob ivfa ilength

log using "IV_tests_tobits.log", replace
foreach y of global varlist {
*Table 7 - tobits
xttobit `y' $X m_* expind $IV, i(pid) ll(0) re
test $IV
xttobit `y' int_am_`y' L.`y' $X m_* expind $IV, i(pid) ll(0) re
test $IV
}
log close

replace houseapp=. if ltsp_dur_house==.
replace electronics=. if ltsp_dur_elec==.

global varlist "anyp electronics houseapp"
log using "IV_tests_probits.log", replace
foreach y of global varlist {
*Table 8 - probits
xtprobit `y' $X m_* expind $IV, i(pid) re
test $IV
xtprobit `y' int_`y' L.`y' $X m_* expind $IV, i(pid) re
test $IV
}
log close

replace cd10new=. if year<1997
replace cd11new=. if year<1997
replace cd12new=. if year<1997
replace cd13new=. if year<1997

global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new cd10new cd11new cd12new cd13new"
log using "IV_tests_probits_product.log", replace
foreach y of global varlist {
*Table 8 - probits
xtprobit `y' $X m_* expind $IV, i(pid) re
desc `y'
test $IV
}
log close

*D2.2 Wu-Hausman tests
log using "Table 7_endogeneity_tests.log", replace
*wu-Hausman exogeneity tests from ivtobit
ivtobit ltsp_dur2 $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr3-yr18) , ll(0) vce(cluster pid) first

ivtobit ltsp_dur2 $X int_am_ltsp_dur2 L.ltsp_dur2 (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr3-yr18), ll(0) vce(cluster pid) first

ivtobit ltsp_dur_elec $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17), ll(0) vce(cluster pid) first

ivtobit ltsp_dur_elec int_am_ltsp_dur_elec L.ltsp_dur_elec $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17), ll(0) vce(cluster pid) first

ivtobit ltsp_dur_house $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17), ll(0) vce(cluster pid) first

ivtobit ltsp_dur_house int_am_ltsp_dur_house L.ltsp_dur_house $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17), ll(0) vce(cluster pid) first
log close

log using "Table 8_endogeneity_tests.log", replace
*wu-Hausman exogeneity tests from ivprobit
ivprobit anyp $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr3-yr18), vce(cluster pid) first

ivprobit anyp $X int_any L.anyp (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr3-yr18), vce(cluster pid) first

ivprobit electronics $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17) if ltsp_dur_elec~=., vce(cluster pid) first

ivprobit electronics $X int_electronics L.electronics (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17) if ltsp_dur_elec~=., vce(cluster pid) first

ivprobit houseapp $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17) if ltsp_dur_house~=., vce(cluster pid) first

ivprobit houseapp $X int_houseapp L.houseapp (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr7-yr17) if ltsp_dur_house~=., vce(cluster pid) first
log close

replace cd10new=. if year<1997
replace cd11new=. if year<1997
replace cd12new=. if year<1997
replace cd13new=. if year<1997

log using "Table 9_endogeneity_tests.log", replace
*wu-Hausman exogeneity tests from ivprobit
global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new cd10new cd11new cd12new cd13new"
foreach y of global varlist  {
desc `y'
ivprobit `y' $X (expind = sex deg alev olev marr white ownor mort rentc llab lnlab lsaved lwealth jbsat hlghq2 ue_all y_up y_down ex_up ex_down mllab mlnlab mlsaved mlwealth *_0 yr3-yr18), vce(cluster pid) first
}
log close

*********************************************************************************************************************************
*purged probabilities
*********************************************************************************************************************************
*Subjective realisation - NC_ALL - 5 purged probabilities
use "U:\Expectations\JMCB revision\gauss\Mark code 21st June 2022\Oct 2022\100 Halton draws KT\FE_dat_shock.dta", clear
g year=1993
replace year=1994 if yr3==1
replace year=1995 if yr4==1
replace year=1996 if yr5==1
replace year=1997 if yr6==1
replace year=1998 if yr7==1
replace year=1999 if yr8==1
replace year=2000 if yr9==1
replace year=2001 if yr10==1
replace year=2002 if yr11==1
replace year=2003 if yr12==1
replace year=2004 if yr13==1
replace year=2005 if yr14==1
replace year=2006 if yr15==1
replace year=2007 if yr16==1
replace year=2008 if yr17==1

g a=1
bys id year: gen b=sum(a)
drop if b==2

keep id pid year p_*

sort id year

cd "U:\Expectations\JMCB revision\"
save probabilities_purged.dta, replace

cd "U:\expectations\"
use "U:\expectations\exp_bal_data.dta", clear
egen id=group(pid)
*merge in predictions from first stage
sort id year
merge id year using "U:\Expectations\JMCB revision\subjective_Y.dta"
drop if _merge==2
drop _merge
sort id year
merge id year using "U:\Expectations\JMCB revision\nominal_Y.dta"
drop if _merge==2
drop _merge
*merge in purged probabilies
sort id year
merge id year using "U:\Expectations\JMCB revision\probabilities_purged.dta"
drop if _merge==2
drop _merge

egen s_GMIOPC=std(GMIOPC)
egen s_GMIOPC_nom=std(GMIOPC_nom)
pwcorr s_GMIOPC s_GMIOPC_nom, sig
twoway (kdensity s_GMIOPC, lcolor(red)) (kdensity s_GMIOPC_nom, lcolor(blue))
drop s_*

global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
*set initial conditions for dynamic models*/
sort pid year
bys pid: gen int_cd1new=cd1new[1]
bys pid: gen int_cd2new=cd2new[1]
bys pid: gen int_cd3new=cd3new[1]
bys pid: gen int_cd4new=cd4new[1]
bys pid: gen int_cd5new=cd5new[1]
bys pid: gen int_cd6new=cd6new[1]
bys pid: gen int_cd7new=cd7new[1]
bys pid: gen int_cd8new=cd8new[1]
bys pid: gen int_cd9new=cd9new[1]

replace tsp_dur=. if year<1997
replace ltsp_dur=. if year<1997

cd "U:\Expectations\JMCB revision\second stage\"
save expenditure_KR_data_august2022.dta, replace

*merge in hid identifier
*Individual variables from source files #_INDRESP*
cd "U:\expectations\data\"
foreach w in a b c d e f g h i j k l m n o p q r{
use `w'hid pid `w'hoh using "U:\BHPS91-08\UKDA-5151-stata8\stata8/`w'indresp.dta",clear
renpfix `w'
ge wave=index("abcdefghijklmnopqr","`w'")
sort hid wave 
saveold ind_bhps_`w', replace
}
use ind_bhps_a, clear
append using ind_bhps_b
append using ind_bhps_c
append using ind_bhps_d
append using ind_bhps_e
append using ind_bhps_f
append using ind_bhps_g
append using ind_bhps_h
append using ind_bhps_i
append using ind_bhps_j
append using ind_bhps_k
append using ind_bhps_l
append using ind_bhps_m
append using ind_bhps_n
append using ind_bhps_o
append using ind_bhps_p
append using ind_bhps_q
append using ind_bhps_r
replace pid=id if wave==16 & pid==.
gen year=1990+wave
keep pid hid year
drop if year==1991
sort pid year
cd "U:\Expectations\JMCB revision\second stage\"
save ind_all_hid.dta, replace

use expenditure_KR_data_august2022.dta, clear
sort pid year
merge pid year using ind_all_hid.dta
drop if _merge==2
drop _merge

sort hid
bys hid year: egen s=sd(ltsp_dur)

keep if hoh==1

replace opt_0=intopt if opt_0==.
replace pess_0=intpess if pess_0==.
replace mllab=Mllab if mllab==.
replace mlnlab=Mlnlab if mlnlab==.
replace mlsaved=Mlsaved if mlsaved==.
replace mlwealth=Mlwealth if mlwealth==.

save expenditure_KR_data_august2022.dta, replace

cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data_august2022.dta, clear
keep if hoh==1

gen houseapp=0
recode houseapp 0=1 if cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1
gen electronics=0
recode electronics 0=1 if cd1new==1 | cd2new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 | cd12new==1
gen ltsp_dur_house=ltsp_dur if houseapp==1 
recode ltsp_dur_house .=0
replace ltsp_dur_house=. if year<1997
gen ltsp_dur_elec=ltsp_dur if electronics==1
recode ltsp_dur_elec .=0
replace ltsp_dur_elec=. if year<1997
gen anyp=0
recode anyp 0=1 if cd1new==1 | cd2new==1 | cd3new==1 | cd4new==1 | cd5new==1 | cd6new==1 | cd7new==1 | cd8new==1 | cd9new==1 | cd10new==1 | cd11new==1 |cd12new==1 |cd1new==13   

recode fisitx 2=-1 3=0
la def fisitx -1"worse off" 0"the same" 1"better off" ,replace
la val fisitx fisitx
recode fisitc 2=-1 3=0
la def fisitc -1"worse off" 0"the same" 1"better off" ,replace
la val fisitc fisitc

replace expind=fisitx if expind==.

sort pid year
bys pid: gen int_am_ltsp_dur2=ltsp_dur2[1]
bys pid: gen int_am_ltsp_dur_elec=ltsp_dur_elec[6] if year>=1997
bys pid: gen int_am_ltsp_dur_house=ltsp_dur_house[6] if year>=1997
bys pid: gen int_anyp=anyp[1]
bys pid: gen int_electronics=electronics[6] if year>=1997
bys pid: gen int_houseapp=houseapp[6] if year>=1997

*create means - Mundlaks
global varlist "age age2 age3 age4 doby doby2 hhsize nch02 nch34 nch511 nch1215 nch1618 nhprobs emp semp unemp lreal_hy"
foreach y of global varlist {
bys pid: egen m_`y'=mean(`y')
}

drop m_doby*
global varlist "ltsp_dur2 ltsp_dur_elec ltsp_dur_house"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy

bys pid: gen nc_opt=sum(cs_o)
bys pid: gen nc_pes=sum(cs_p)
bys pid: gen nc_sam=sum(cs_s)
egen nc_all=rowtotal(nc_opt nc_pes nc_sam)

replace houseapp=. if ltsp_dur_house==.
replace electronics=. if ltsp_dur_elec==.

*standardise
egen s_expind=std(expind)
egen s_OP=std(GMIOPC)
egen s_GMIOPC=std(OP)
drop expind OP GMIOPC
renpfix s_

save expenditure_KR_data.dta, replace
*********************************************************************************************************************************
*E1 Expenditure amounts using purged probabilities
*********************************************************************************************************************************
cd "U:\Expectations\JMCB revision\second stage\"
use expenditure_KR_data.dta, clear

global varlist "ltsp_dur2 ltsp_dur_elec"
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy

*MEs using scaling factor
log using "fullMEs table 7_purged_probabilities.log", replace
foreach y of global varlist  {
*static
desc `y' 
desc `y' 
xttobit `y' $X m_* p_Up* p_Down*, i(pid) ll(0) re nonrtolerance /*endogenous static*/
test p_DownTemp=p_UpTemp /*A=C eq.1*/
test p_Up=p_Down /*better off = worse off*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1
margins, dydx(p_*) predict(pr(0,.))
margins, dydx(p_*) predict(e(0,.))

*dynamic
desc `y' 
xttobit `y' int_am_`y' L.`y' $X m_* p_Up* p_Down*, i(pid) ll(0) re nonrtolerance /*endogenous dynamic*/
test p_DownTemp=p_UpTemp /*A=C eq.1*/
test p_Up=p_Down /*better off = worse off*/
mat ME2=(e(N_lc)/e(N))*e(b)
mat V2=(e(N_lc)/e(N))*e(V)
mat VAR2=vecdiag(e(V))
matmap VAR2 SE2, map(sqrt(@))
mat SE2=SE2*(e(N_lc)/e(N))
mat li ME2
mat li SE2
margins, dydx(L.`y' p_*) predict(pr(0,.))
margins, dydx(L.`y' p_*) predict(e(0,.))
}
log close

log using "fullMEs table 7_purged_probabilities.log", append
tobit ltsp_dur_house $X m_* p_Up* p_Down*, vce(cluster pid) ll(0) /*endogenous static*/
test p_DownTemp=p_UpTemp /*A=C eq.1*/
test p_Up=p_Down /*better off = worse off*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1
margins, dydx(p_*) predict(pr(0,.))
margins, dydx(p_*) predict(e(0,.))

tobit ltsp_dur_house int_am_ltsp_dur_house L.ltsp_dur_house $X m_* p_Up* p_Down*, vce(cluster pid) ll(0) /*endogenous dynamic*/
test p_DownTemp=p_UpTemp /*A=C eq.1*/
test p_Up=p_Down /*better off = worse off*/
mat ME1=(e(N_lc)/e(N))*e(b)
mat V1=(e(N_lc)/e(N))*e(V)
mat VAR1=vecdiag(e(V))
matmap VAR1 SE1, map(sqrt(@))
mat SE1=SE1*(e(N_lc)/e(N))
mat li ME1
mat li SE1
margins, dydx(L.ltsp_dur_house p_*) predict(pr(0,.))
margins, dydx(L.ltsp_dur_house p_*) predict(e(0,.))
log close

*********************************************************************************************************************************
*E2 Likelihood of expenditure using purged probabilities
*********************************************************************************************************************************
sort pid year

g lag_anyp=L.anyp
g lag_electronics=L.electronics
g lag_houseapp=L.houseapp

global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "anyp electronics houseapp"

cd "U:\Expectations\JMCB revision\second stage\"

log using "fullMEs table 8_purged_probabilities.log", replace
foreach y of global varlist  {
*static
xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* p_Up* p_Down*, i(pid) re
test p_DownTemp=p_UpTemp /*A=C eq.1*/
test p_Up=p_Down /*better off = worse off*/
margins, dydx(p_*)
*dynamic
xtlogit `y' int_`y' lag_`y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* p_Up* p_Down*, i(pid) re 
test p_DownTemp=p_UpTemp /*A=C eq.1*/
margins, dydx(lag_* p_*)
}
log close

*********************************************************************************************************************************
*E3 Likelihood of expenditure type using purged probabilities - full sample
*********************************************************************************************************************************
global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "cd1new cd2new cd3new cd4new cd5new cd6new cd7new cd8new cd9new"

cd "U:\Expectations\JMCB revision\second stage\"

log using "fullMEs table 9_purged_probabilities.log", replace
foreach y of global varlist  {
xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* p_Up p_DownTemp p_No* p_UpTemp, i(pid) re
margins, dydx(p_*)
}
log close

*********************************************************************************************************************************
*E4 Likelihood of expenditure type using purged probabilities - sub-sample 1997+
*********************************************************************************************************************************
replace cd10new=. if year<1997
replace cd11new=. if year<1997
replace cd12new=. if year<1997
replace cd13new=. if year<1997

global X age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy
global varlist "cd10new cd11new cd12new cd13new"

cd "U:\Expectations\JMCB revision\second stage\"

log using "fullMEs table 9_purged_probabilities.log", append
foreach y of global varlist  {
xtlogit `y' age age2 age3 age4 doby* hhsize nch* nhprobs emp semp unemp lreal_hy m_* p_Up p_DownTemp p_No* p_UpTemp, i(pid) re
margins, dydx(p_*)
}
log close